/* backend.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from backend.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Alban Crequy <alban.crequy@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gobject/gvaluecollector.h>


#define LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW (libsocialweb_test_contact_view_get_type ())
#define LIBSOCIALWEB_TEST_CONTACT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW, LibsocialwebTestContactView))
#define LIBSOCIALWEB_TEST_IS_CONTACT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW))
#define LIBSOCIALWEB_TEST_CONTACT_VIEW_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW, LibsocialwebTestContactViewIface))

typedef struct _LibsocialwebTestContactView LibsocialwebTestContactView;
typedef struct _LibsocialwebTestContactViewIface LibsocialwebTestContactViewIface;

#define LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW_PROXY (libsocialweb_test_contact_view_proxy_get_type ())

#define LIBSOCIALWEB_TEST_CONTACT_VIEW_TYPE_CONTACTS_ADDED_ELEMENT (libsocialweb_test_contact_view_contacts_added_element_get_type ())
typedef struct _LibsocialwebTestContactViewContactsAddedElement LibsocialwebTestContactViewContactsAddedElement;

#define LIBSOCIALWEB_TEST_CONTACT_VIEW_TYPE_CONTACTS_REMOVED_ELEMENT (libsocialweb_test_contact_view_contacts_removed_element_get_type ())
typedef struct _LibsocialwebTestContactViewContactsRemovedElement LibsocialwebTestContactViewContactsRemovedElement;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
typedef GDBusProxy LibsocialwebTestContactViewProxy;
typedef GDBusProxyClass LibsocialwebTestContactViewProxyClass;

#define LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST (libsocialweb_test_libsocialweb_contact_view_test_get_type ())
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_CONTACT_VIEW_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, LibsocialwebTestLibsocialwebContactViewTest))
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_CONTACT_VIEW_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, LibsocialwebTestLibsocialwebContactViewTestClass))
#define LIBSOCIALWEB_TEST_IS_LIBSOCIALWEB_CONTACT_VIEW_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST))
#define LIBSOCIALWEB_TEST_IS_LIBSOCIALWEB_CONTACT_VIEW_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST))
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_CONTACT_VIEW_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, LibsocialwebTestLibsocialwebContactViewTestClass))

typedef struct _LibsocialwebTestLibsocialwebContactViewTest LibsocialwebTestLibsocialwebContactViewTest;
typedef struct _LibsocialwebTestLibsocialwebContactViewTestClass LibsocialwebTestLibsocialwebContactViewTestClass;
typedef struct _LibsocialwebTestLibsocialwebContactViewTestPrivate LibsocialwebTestLibsocialwebContactViewTestPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_CONTACT_VIEW_TEST_TYPE_CONTACTS_ADDED_ELEMENT (libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_get_type ())
typedef struct _LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement;

#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_CONTACT_VIEW_TEST_TYPE_CONTACTS_REMOVED_ELEMENT (libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_get_type ())
typedef struct _LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement;

#define LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST (libsocialweb_test_libsocialweb_service_capabilities_test_get_type ())
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST, LibsocialwebTestLibsocialwebServiceCapabilitiesTest))
#define LIBSOCIALWEB_TEST_IS_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST))
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST, LibsocialwebTestLibsocialwebServiceCapabilitiesTestIface))

typedef struct _LibsocialwebTestLibsocialwebServiceCapabilitiesTest LibsocialwebTestLibsocialwebServiceCapabilitiesTest;
typedef struct _LibsocialwebTestLibsocialwebServiceCapabilitiesTestIface LibsocialwebTestLibsocialwebServiceCapabilitiesTestIface;

#define LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST_PROXY (libsocialweb_test_libsocialweb_service_capabilities_test_proxy_get_type ())
typedef GDBusProxy LibsocialwebTestLibsocialwebServiceCapabilitiesTestProxy;
typedef GDBusProxyClass LibsocialwebTestLibsocialwebServiceCapabilitiesTestProxyClass;

#define LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_QUERY_TEST (libsocialweb_test_libsocialweb_service_query_test_get_type ())
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_QUERY_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_QUERY_TEST, LibsocialwebTestLibsocialwebServiceQueryTest))
#define LIBSOCIALWEB_TEST_IS_LIBSOCIALWEB_SERVICE_QUERY_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_QUERY_TEST))
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_QUERY_TEST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_QUERY_TEST, LibsocialwebTestLibsocialwebServiceQueryTestIface))

typedef struct _LibsocialwebTestLibsocialwebServiceQueryTest LibsocialwebTestLibsocialwebServiceQueryTest;
typedef struct _LibsocialwebTestLibsocialwebServiceQueryTestIface LibsocialwebTestLibsocialwebServiceQueryTestIface;

#define LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_QUERY_TEST_PROXY (libsocialweb_test_libsocialweb_service_query_test_proxy_get_type ())
typedef GDBusProxy LibsocialwebTestLibsocialwebServiceQueryTestProxy;
typedef GDBusProxyClass LibsocialwebTestLibsocialwebServiceQueryTestProxyClass;

#define LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST (libsocialweb_test_libsocialweb_service_test_get_type ())
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST, LibsocialwebTestLibsocialwebServiceTest))
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST, LibsocialwebTestLibsocialwebServiceTestClass))
#define LIBSOCIALWEB_TEST_IS_LIBSOCIALWEB_SERVICE_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST))
#define LIBSOCIALWEB_TEST_IS_LIBSOCIALWEB_SERVICE_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST))
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST, LibsocialwebTestLibsocialwebServiceTestClass))

typedef struct _LibsocialwebTestLibsocialwebServiceTest LibsocialwebTestLibsocialwebServiceTest;
typedef struct _LibsocialwebTestLibsocialwebServiceTestClass LibsocialwebTestLibsocialwebServiceTestClass;
typedef struct _LibsocialwebTestLibsocialwebServiceTestPrivate LibsocialwebTestLibsocialwebServiceTestPrivate;

#define LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST (libsocialweb_test_libsocialweb_server_test_get_type ())
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVER_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST, LibsocialwebTestLibsocialwebServerTest))
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVER_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST, LibsocialwebTestLibsocialwebServerTestClass))
#define LIBSOCIALWEB_TEST_IS_LIBSOCIALWEB_SERVER_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST))
#define LIBSOCIALWEB_TEST_IS_LIBSOCIALWEB_SERVER_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST))
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVER_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST, LibsocialwebTestLibsocialwebServerTestClass))

typedef struct _LibsocialwebTestLibsocialwebServerTest LibsocialwebTestLibsocialwebServerTest;
typedef struct _LibsocialwebTestLibsocialwebServerTestClass LibsocialwebTestLibsocialwebServerTestClass;
typedef struct _LibsocialwebTestLibsocialwebServerTestPrivate LibsocialwebTestLibsocialwebServerTestPrivate;

#define LIBSOCIALWEB_TEST_TYPE_BACKEND (libsocialweb_test_backend_get_type ())
#define LIBSOCIALWEB_TEST_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackend))
#define LIBSOCIALWEB_TEST_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackendClass))
#define LIBSOCIALWEB_TEST_IS_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBSOCIALWEB_TEST_TYPE_BACKEND))
#define LIBSOCIALWEB_TEST_IS_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBSOCIALWEB_TEST_TYPE_BACKEND))
#define LIBSOCIALWEB_TEST_BACKEND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackendClass))

typedef struct _LibsocialwebTestBackend LibsocialwebTestBackend;
typedef struct _LibsocialwebTestBackendClass LibsocialwebTestBackendClass;
typedef struct _LibsocialwebTestBackendPrivate LibsocialwebTestBackendPrivate;
typedef struct _LibsocialwebTestParamSpecBackend LibsocialwebTestParamSpecBackend;

struct _LibsocialwebTestContactViewIface {
	GTypeInterface parent_iface;
	void (*Close) (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*Close_finish) (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
	void (*Refresh) (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*Refresh_finish) (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
	void (*Start) (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*Start_finish) (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
	void (*Stop) (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*Stop_finish) (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
};

struct _LibsocialwebTestContactViewContactsAddedElement {
	gchar* service;
	gchar* id;
	gint64 time;
	GVariant* attrs;
};

struct _LibsocialwebTestContactViewContactsRemovedElement {
	gchar* service;
	gchar* id;
};

struct _LibsocialwebTestLibsocialwebContactViewTest {
	GObject parent_instance;
	LibsocialwebTestLibsocialwebContactViewTestPrivate * priv;
	gchar* query;
	gchar* path;
};

struct _LibsocialwebTestLibsocialwebContactViewTestClass {
	GObjectClass parent_class;
};

struct _LibsocialwebTestLibsocialwebContactViewTestPrivate {
	GHashTable* p;
};

struct _LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement {
	gchar* service;
	gchar* id;
	gint64 time;
	GVariant* attrs;
};

struct _LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement {
	gchar* service;
	gchar* id;
};

struct _LibsocialwebTestLibsocialwebServiceCapabilitiesTestIface {
	GTypeInterface parent_iface;
	gchar** (*GetStaticCapabilities) (LibsocialwebTestLibsocialwebServiceCapabilitiesTest* self, int* result_length1, GError** error);
};

struct _LibsocialwebTestLibsocialwebServiceQueryTestIface {
	GTypeInterface parent_iface;
	char* (*OpenView) (LibsocialwebTestLibsocialwebServiceQueryTest* self, const gchar* query, GHashTable* p, GError** error);
};

struct _LibsocialwebTestLibsocialwebServiceTest {
	GObject parent_instance;
	LibsocialwebTestLibsocialwebServiceTestPrivate * priv;
	GeeHashMap* contact_views;
};

struct _LibsocialwebTestLibsocialwebServiceTestClass {
	GObjectClass parent_class;
};

struct _LibsocialwebTestLibsocialwebServiceTestPrivate {
	gchar* service_name;
};

struct _LibsocialwebTestLibsocialwebServerTest {
	GObject parent_instance;
	LibsocialwebTestLibsocialwebServerTestPrivate * priv;
};

struct _LibsocialwebTestLibsocialwebServerTestClass {
	GObjectClass parent_class;
};

struct _LibsocialwebTestLibsocialwebServerTestPrivate {
	gchar** services;
	gint services_length1;
	gint _services_size_;
	GDBusConnection* _conn;
	guint* _registrations;
	gint _registrations_length1;
	gint __registrations_size_;
	GHashTable* _register_child_signals;
};

struct _LibsocialwebTestBackend {
	GTypeInstance parent_instance;
	volatile int ref_count;
	LibsocialwebTestBackendPrivate * priv;
};

struct _LibsocialwebTestBackendClass {
	GTypeClass parent_class;
	void (*finalize) (LibsocialwebTestBackend *self);
};

struct _LibsocialwebTestBackendPrivate {
	gboolean _debug;
	LibsocialwebTestLibsocialwebServerTest* _lsw_server;
	guint _name_id;
};

struct _LibsocialwebTestParamSpecBackend {
	GParamSpec parent_instance;
};


static gpointer libsocialweb_test_libsocialweb_contact_view_test_parent_class = NULL;
static gpointer libsocialweb_test_libsocialweb_service_test_parent_class = NULL;
static gint libsocialweb_test_libsocialweb_service_test_view_count;
static gint libsocialweb_test_libsocialweb_service_test_view_count = 0;
static LibsocialwebTestLibsocialwebServiceCapabilitiesTestIface* libsocialweb_test_libsocialweb_service_test_libsocialweb_test_libsocialweb_service_capabilities_test_parent_iface = NULL;
static LibsocialwebTestLibsocialwebServiceQueryTestIface* libsocialweb_test_libsocialweb_service_test_libsocialweb_test_libsocialweb_service_query_test_parent_iface = NULL;
static gpointer libsocialweb_test_libsocialweb_server_test_parent_class = NULL;
static gpointer libsocialweb_test_backend_parent_class = NULL;

GType libsocialweb_test_contact_view_proxy_get_type (void) G_GNUC_CONST;
guint libsocialweb_test_contact_view_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
GType libsocialweb_test_contact_view_get_type (void) G_GNUC_CONST;
void libsocialweb_test_contact_view_Close (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void libsocialweb_test_contact_view_Close_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
void libsocialweb_test_contact_view_Refresh (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void libsocialweb_test_contact_view_Refresh_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
void libsocialweb_test_contact_view_Start (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void libsocialweb_test_contact_view_Start_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
void libsocialweb_test_contact_view_Stop (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void libsocialweb_test_contact_view_Stop_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
GType libsocialweb_test_contact_view_contacts_added_element_get_type (void) G_GNUC_CONST;
LibsocialwebTestContactViewContactsAddedElement* libsocialweb_test_contact_view_contacts_added_element_dup (const LibsocialwebTestContactViewContactsAddedElement* self);
void libsocialweb_test_contact_view_contacts_added_element_free (LibsocialwebTestContactViewContactsAddedElement* self);
void libsocialweb_test_contact_view_contacts_added_element_copy (const LibsocialwebTestContactViewContactsAddedElement* self, LibsocialwebTestContactViewContactsAddedElement* dest);
void libsocialweb_test_contact_view_contacts_added_element_destroy (LibsocialwebTestContactViewContactsAddedElement* self);
static void g_cclosure_user_marshal_VOID__POINTER_INT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
GType libsocialweb_test_contact_view_contacts_removed_element_get_type (void) G_GNUC_CONST;
LibsocialwebTestContactViewContactsRemovedElement* libsocialweb_test_contact_view_contacts_removed_element_dup (const LibsocialwebTestContactViewContactsRemovedElement* self);
void libsocialweb_test_contact_view_contacts_removed_element_free (LibsocialwebTestContactViewContactsRemovedElement* self);
void libsocialweb_test_contact_view_contacts_removed_element_copy (const LibsocialwebTestContactViewContactsRemovedElement* self, LibsocialwebTestContactViewContactsRemovedElement* dest);
void libsocialweb_test_contact_view_contacts_removed_element_destroy (LibsocialwebTestContactViewContactsRemovedElement* self);
static void libsocialweb_test_contact_view_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static void _vala_LibsocialwebTestContactViewContactsAddedElement_array_free (LibsocialwebTestContactViewContactsAddedElement* array, gint array_length);
static void _dbus_handle_libsocialweb_test_contact_view_contacts_added (LibsocialwebTestContactView* self, GVariant* parameters);
static void _dbus_handle_libsocialweb_test_contact_view_contacts_changed (LibsocialwebTestContactView* self, GVariant* parameters);
static void _vala_LibsocialwebTestContactViewContactsRemovedElement_array_free (LibsocialwebTestContactViewContactsRemovedElement* array, gint array_length);
static void _dbus_handle_libsocialweb_test_contact_view_contacts_removed (LibsocialwebTestContactView* self, GVariant* parameters);
static void _vala_g_async_ready_callback (GObject *source_object, GAsyncResult *res, void *user_data);
static void libsocialweb_test_contact_view_proxy_Close_async (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void libsocialweb_test_contact_view_proxy_Close_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
static void libsocialweb_test_contact_view_proxy_Refresh_async (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void libsocialweb_test_contact_view_proxy_Refresh_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
static void libsocialweb_test_contact_view_proxy_Start_async (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void libsocialweb_test_contact_view_proxy_Start_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
static void libsocialweb_test_contact_view_proxy_Stop_async (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void libsocialweb_test_contact_view_proxy_Stop_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error);
static void libsocialweb_test_contact_view_proxy_libsocialweb_test_contact_view_interface_init (LibsocialwebTestContactViewIface* iface);
static void _dbus_libsocialweb_test_contact_view_Close (LibsocialwebTestContactView* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_libsocialweb_test_contact_view_Close_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_);
static void _dbus_libsocialweb_test_contact_view_Refresh (LibsocialwebTestContactView* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_libsocialweb_test_contact_view_Refresh_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_);
static void _dbus_libsocialweb_test_contact_view_Start (LibsocialwebTestContactView* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_libsocialweb_test_contact_view_Start_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_);
static void _dbus_libsocialweb_test_contact_view_Stop (LibsocialwebTestContactView* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_libsocialweb_test_contact_view_Stop_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_);
static void libsocialweb_test_contact_view_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* libsocialweb_test_contact_view_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static gboolean libsocialweb_test_contact_view_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_libsocialweb_test_contact_view_contacts_added (GObject* _sender, LibsocialwebTestContactViewContactsAddedElement* contacts, int contacts_length1, gpointer* _data);
static void _dbus_libsocialweb_test_contact_view_contacts_changed (GObject* _sender, LibsocialwebTestContactViewContactsAddedElement* contacts, int contacts_length1, gpointer* _data);
static void _dbus_libsocialweb_test_contact_view_contacts_removed (GObject* _sender, LibsocialwebTestContactViewContactsRemovedElement* contacts, int contacts_length1, gpointer* _data);
static void _libsocialweb_test_contact_view_unregister_object (gpointer user_data);
GType libsocialweb_test_libsocialweb_contact_view_test_get_type (void) G_GNUC_CONST;
guint libsocialweb_test_libsocialweb_contact_view_test_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_CONTACT_VIEW_TEST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, LibsocialwebTestLibsocialwebContactViewTestPrivate))
enum  {
	LIBSOCIALWEB_TEST_LIBSOCIALWEB_CONTACT_VIEW_TEST_DUMMY_PROPERTY
};
LibsocialwebTestLibsocialwebContactViewTest* libsocialweb_test_libsocialweb_contact_view_test_new (const gchar* query, GHashTable* p, const gchar* path);
LibsocialwebTestLibsocialwebContactViewTest* libsocialweb_test_libsocialweb_contact_view_test_construct (GType object_type, const gchar* query, GHashTable* p, const gchar* path);
void libsocialweb_test_libsocialweb_contact_view_test_Close (LibsocialwebTestLibsocialwebContactViewTest* self);
void libsocialweb_test_libsocialweb_contact_view_test_Refresh (LibsocialwebTestLibsocialwebContactViewTest* self);
void libsocialweb_test_libsocialweb_contact_view_test_Start (LibsocialwebTestLibsocialwebContactViewTest* self);
void libsocialweb_test_libsocialweb_contact_view_test_Stop (LibsocialwebTestLibsocialwebContactViewTest* self);
void libsocialweb_test_libsocialweb_contact_view_test_EmitContactsAdded (LibsocialwebTestLibsocialwebContactViewTest* self, const gchar* text);
#define LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_IFACE "org.gnome.libsocialweb"
void libsocialweb_test_libsocialweb_contact_view_test_EmitContactsChanged (LibsocialwebTestLibsocialwebContactViewTest* self, const gchar* text);
void libsocialweb_test_libsocialweb_contact_view_test_EmitContactsRemoved (LibsocialwebTestLibsocialwebContactViewTest* self, const gchar* text);
GType libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_get_type (void) G_GNUC_CONST;
LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_dup (const LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* self);
void libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_free (LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* self);
void libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_copy (const LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* self, LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* dest);
void libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_destroy (LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* self);
GType libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_get_type (void) G_GNUC_CONST;
LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_dup (const LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* self);
void libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_free (LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* self);
void libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_copy (const LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* self, LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* dest);
void libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_destroy (LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* self);
static void libsocialweb_test_libsocialweb_contact_view_test_finalize (GObject* obj);
static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_Close (LibsocialwebTestLibsocialwebContactViewTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_Refresh (LibsocialwebTestLibsocialwebContactViewTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_Start (LibsocialwebTestLibsocialwebContactViewTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_Stop (LibsocialwebTestLibsocialwebContactViewTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static gboolean libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_added (GObject* _sender, LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* contacts, int contacts_length1, gpointer* _data);
static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_changed (GObject* _sender, LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* contacts, int contacts_length1, gpointer* _data);
static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_removed (GObject* _sender, LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* contacts, int contacts_length1, gpointer* _data);
static void _libsocialweb_test_libsocialweb_contact_view_test_unregister_object (gpointer user_data);
GType libsocialweb_test_libsocialweb_service_capabilities_test_proxy_get_type (void) G_GNUC_CONST;
guint libsocialweb_test_libsocialweb_service_capabilities_test_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
GType libsocialweb_test_libsocialweb_service_capabilities_test_get_type (void) G_GNUC_CONST;
gchar** libsocialweb_test_libsocialweb_service_capabilities_test_GetStaticCapabilities (LibsocialwebTestLibsocialwebServiceCapabilitiesTest* self, int* result_length1, GError** error);
static void libsocialweb_test_libsocialweb_service_capabilities_test_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static gchar** libsocialweb_test_libsocialweb_service_capabilities_test_proxy_GetStaticCapabilities (LibsocialwebTestLibsocialwebServiceCapabilitiesTest* self, int* result_length1, GError** error);
static void libsocialweb_test_libsocialweb_service_capabilities_test_proxy_libsocialweb_test_libsocialweb_service_capabilities_test_interface_init (LibsocialwebTestLibsocialwebServiceCapabilitiesTestIface* iface);
static void _dbus_libsocialweb_test_libsocialweb_service_capabilities_test_GetStaticCapabilities (LibsocialwebTestLibsocialwebServiceCapabilitiesTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static gboolean libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _libsocialweb_test_libsocialweb_service_capabilities_test_unregister_object (gpointer user_data);
GType libsocialweb_test_libsocialweb_service_query_test_proxy_get_type (void) G_GNUC_CONST;
guint libsocialweb_test_libsocialweb_service_query_test_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
GType libsocialweb_test_libsocialweb_service_query_test_get_type (void) G_GNUC_CONST;
char* libsocialweb_test_libsocialweb_service_query_test_OpenView (LibsocialwebTestLibsocialwebServiceQueryTest* self, const gchar* query, GHashTable* p, GError** error);
static void libsocialweb_test_libsocialweb_service_query_test_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static char* libsocialweb_test_libsocialweb_service_query_test_proxy_OpenView (LibsocialwebTestLibsocialwebServiceQueryTest* self, const gchar* query, GHashTable* p, GError** error);
static void libsocialweb_test_libsocialweb_service_query_test_proxy_libsocialweb_test_libsocialweb_service_query_test_interface_init (LibsocialwebTestLibsocialwebServiceQueryTestIface* iface);
static void _dbus_libsocialweb_test_libsocialweb_service_query_test_OpenView (LibsocialwebTestLibsocialwebServiceQueryTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void libsocialweb_test_libsocialweb_service_query_test_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* libsocialweb_test_libsocialweb_service_query_test_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static gboolean libsocialweb_test_libsocialweb_service_query_test_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _libsocialweb_test_libsocialweb_service_query_test_unregister_object (gpointer user_data);
GType libsocialweb_test_libsocialweb_service_test_get_type (void) G_GNUC_CONST;
guint libsocialweb_test_libsocialweb_service_test_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_TEST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST, LibsocialwebTestLibsocialwebServiceTestPrivate))
enum  {
	LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_TEST_DUMMY_PROPERTY
};
LibsocialwebTestLibsocialwebServiceTest* libsocialweb_test_libsocialweb_service_test_new (const gchar* service_name);
LibsocialwebTestLibsocialwebServiceTest* libsocialweb_test_libsocialweb_service_test_construct (GType object_type, const gchar* service_name);
static char* libsocialweb_test_libsocialweb_service_test_real_OpenView (LibsocialwebTestLibsocialwebServiceQueryTest* base, const gchar* query, GHashTable* p, GError** error);
#define LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_PATH "/org/gnome/libsocialweb"
static gchar** libsocialweb_test_libsocialweb_service_test_real_GetStaticCapabilities (LibsocialwebTestLibsocialwebServiceCapabilitiesTest* base, int* result_length1, GError** error);
static void _vala_array_add1 (gchar*** array, int* length, int* size, gchar* value);
static void g_cclosure_user_marshal_VOID__STRING_BOXED_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void libsocialweb_test_libsocialweb_service_test_finalize (GObject* obj);
static void _dbus_libsocialweb_test_libsocialweb_service_test_OpenView (LibsocialwebTestLibsocialwebServiceTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_libsocialweb_test_libsocialweb_service_test_GetStaticCapabilities (LibsocialwebTestLibsocialwebServiceTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void libsocialweb_test_libsocialweb_service_test_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* libsocialweb_test_libsocialweb_service_test_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static gboolean libsocialweb_test_libsocialweb_service_test_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_libsocialweb_test_libsocialweb_service_test_registered_child (GObject* _sender, guint id, gpointer* _data);
static void _libsocialweb_test_libsocialweb_service_test_unregister_object (gpointer user_data);
GType libsocialweb_test_libsocialweb_server_test_get_type (void) G_GNUC_CONST;
guint libsocialweb_test_libsocialweb_server_test_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
#define LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVER_TEST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST, LibsocialwebTestLibsocialwebServerTestPrivate))
enum  {
	LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVER_TEST_DUMMY_PROPERTY
};
LibsocialwebTestLibsocialwebServerTest* libsocialweb_test_libsocialweb_server_test_new (void);
LibsocialwebTestLibsocialwebServerTest* libsocialweb_test_libsocialweb_server_test_construct (GType object_type);
static void _g_object_unref0_ (gpointer var);
gboolean libsocialweb_test_libsocialweb_server_test_is_online (LibsocialwebTestLibsocialwebServerTest* self);
gchar** libsocialweb_test_libsocialweb_server_test_get_services (LibsocialwebTestLibsocialwebServerTest* self, int* result_length1);
static gchar** _vala_array_dup1 (gchar** self, int length);
LibsocialwebTestLibsocialwebServiceTest* libsocialweb_test_libsocialweb_server_test_add_service (LibsocialwebTestLibsocialwebServerTest* self, const gchar* service_name);
static void __lambda3_ (LibsocialwebTestLibsocialwebServerTest* self, guint id);
static void _vala_array_add2 (guint** array, int* length, int* size, guint value);
static void ___lambda3__libsocialweb_test_libsocialweb_service_test_registered_child (LibsocialwebTestLibsocialwebServiceTest* _sender, guint id, gpointer self);
static void _vala_array_add3 (guint** array, int* length, int* size, guint value);
static void _vala_array_add4 (guint** array, int* length, int* size, guint value);
static void _vala_array_add5 (gchar*** array, int* length, int* size, gchar* value);
void libsocialweb_test_libsocialweb_server_test_register (LibsocialwebTestLibsocialwebServerTest* self);
static void _vala_array_add6 (guint** array, int* length, int* size, guint value);
void libsocialweb_test_libsocialweb_server_test_unregister (LibsocialwebTestLibsocialwebServerTest* self);
static void libsocialweb_test_libsocialweb_server_test_finalize (GObject* obj);
static void _dbus_libsocialweb_test_libsocialweb_server_test_is_online (LibsocialwebTestLibsocialwebServerTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_libsocialweb_test_libsocialweb_server_test_get_services (LibsocialwebTestLibsocialwebServerTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void libsocialweb_test_libsocialweb_server_test_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* libsocialweb_test_libsocialweb_server_test_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static gboolean libsocialweb_test_libsocialweb_server_test_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _libsocialweb_test_libsocialweb_server_test_unregister_object (gpointer user_data);
gpointer libsocialweb_test_backend_ref (gpointer instance);
void libsocialweb_test_backend_unref (gpointer instance);
GParamSpec* libsocialweb_test_param_spec_backend (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void libsocialweb_test_value_set_backend (GValue* value, gpointer v_object);
void libsocialweb_test_value_take_backend (GValue* value, gpointer v_object);
gpointer libsocialweb_test_value_get_backend (const GValue* value);
GType libsocialweb_test_backend_get_type (void) G_GNUC_CONST;
#define LIBSOCIALWEB_TEST_BACKEND_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackendPrivate))
enum  {
	LIBSOCIALWEB_TEST_BACKEND_DUMMY_PROPERTY
};
#define LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_BUS_NAME "org.gnome.libsocialweb"
LibsocialwebTestBackend* libsocialweb_test_backend_new (void);
LibsocialwebTestBackend* libsocialweb_test_backend_construct (GType object_type);
void libsocialweb_test_backend_set_debug (LibsocialwebTestBackend* self, gboolean value);
void libsocialweb_test_backend_set_up (LibsocialwebTestBackend* self);
static void libsocialweb_test_backend_on_bus_aquired (LibsocialwebTestBackend* self, GDBusConnection* conn);
static void _libsocialweb_test_backend_on_bus_aquired_gbus_acquired_callback (GDBusConnection* connection, const gchar* name, gpointer self);
static void __lambda4_ (LibsocialwebTestBackend* self);
static void ___lambda4__gbus_name_acquired_callback (GDBusConnection* connection, const gchar* name, gpointer self);
static void __lambda5_ (LibsocialwebTestBackend* self);
static void ___lambda5__gbus_name_lost_callback (GDBusConnection* connection, const gchar* name, gpointer self);
LibsocialwebTestLibsocialwebServiceTest* libsocialweb_test_backend_add_service (LibsocialwebTestBackend* self, const gchar* service_name);
void libsocialweb_test_backend_tear_down (LibsocialwebTestBackend* self);
gboolean libsocialweb_test_backend_get_debug (LibsocialwebTestBackend* self);
static void libsocialweb_test_backend_finalize (LibsocialwebTestBackend* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_Close_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_Close_out[] = {NULL};
static const GDBusMethodInfo _libsocialweb_test_contact_view_dbus_method_info_Close = {-1, "Close", (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_Close_in), (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_Close_out)};
static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_Refresh_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_Refresh_out[] = {NULL};
static const GDBusMethodInfo _libsocialweb_test_contact_view_dbus_method_info_Refresh = {-1, "Refresh", (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_Refresh_in), (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_Refresh_out)};
static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_Start_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_Start_out[] = {NULL};
static const GDBusMethodInfo _libsocialweb_test_contact_view_dbus_method_info_Start = {-1, "Start", (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_Start_in), (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_Start_out)};
static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_Stop_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_Stop_out[] = {NULL};
static const GDBusMethodInfo _libsocialweb_test_contact_view_dbus_method_info_Stop = {-1, "Stop", (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_Stop_in), (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_Stop_out)};
static const GDBusMethodInfo * const _libsocialweb_test_contact_view_dbus_method_info[] = {&_libsocialweb_test_contact_view_dbus_method_info_Close, &_libsocialweb_test_contact_view_dbus_method_info_Refresh, &_libsocialweb_test_contact_view_dbus_method_info_Start, &_libsocialweb_test_contact_view_dbus_method_info_Stop, NULL};
static const GDBusArgInfo _libsocialweb_test_contact_view_dbus_arg_info_contacts_added_contacts = {-1, "contacts", "a(ssxa{sas})"};
static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_contacts_added[] = {&_libsocialweb_test_contact_view_dbus_arg_info_contacts_added_contacts, NULL};
static const GDBusSignalInfo _libsocialweb_test_contact_view_dbus_signal_info_contacts_added = {-1, "ContactsAdded", (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_contacts_added)};
static const GDBusArgInfo _libsocialweb_test_contact_view_dbus_arg_info_contacts_changed_contacts = {-1, "contacts", "a(ssxa{sas})"};
static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_contacts_changed[] = {&_libsocialweb_test_contact_view_dbus_arg_info_contacts_changed_contacts, NULL};
static const GDBusSignalInfo _libsocialweb_test_contact_view_dbus_signal_info_contacts_changed = {-1, "ContactsChanged", (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_contacts_changed)};
static const GDBusArgInfo _libsocialweb_test_contact_view_dbus_arg_info_contacts_removed_contacts = {-1, "contacts", "a(ss)"};
static const GDBusArgInfo * const _libsocialweb_test_contact_view_dbus_arg_info_contacts_removed[] = {&_libsocialweb_test_contact_view_dbus_arg_info_contacts_removed_contacts, NULL};
static const GDBusSignalInfo _libsocialweb_test_contact_view_dbus_signal_info_contacts_removed = {-1, "ContactsRemoved", (GDBusArgInfo **) (&_libsocialweb_test_contact_view_dbus_arg_info_contacts_removed)};
static const GDBusSignalInfo * const _libsocialweb_test_contact_view_dbus_signal_info[] = {&_libsocialweb_test_contact_view_dbus_signal_info_contacts_added, &_libsocialweb_test_contact_view_dbus_signal_info_contacts_changed, &_libsocialweb_test_contact_view_dbus_signal_info_contacts_removed, NULL};
static const GDBusPropertyInfo * const _libsocialweb_test_contact_view_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _libsocialweb_test_contact_view_dbus_interface_info = {-1, "org.gnome.libsocialweb.ContactView", (GDBusMethodInfo **) (&_libsocialweb_test_contact_view_dbus_method_info), (GDBusSignalInfo **) (&_libsocialweb_test_contact_view_dbus_signal_info), (GDBusPropertyInfo **) (&_libsocialweb_test_contact_view_dbus_property_info)};
static const GDBusInterfaceVTable _libsocialweb_test_contact_view_dbus_interface_vtable = {libsocialweb_test_contact_view_dbus_interface_method_call, libsocialweb_test_contact_view_dbus_interface_get_property, libsocialweb_test_contact_view_dbus_interface_set_property};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Close_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Close_out[] = {NULL};
static const GDBusMethodInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_method_info_Close = {-1, "Close", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Close_in), (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Close_out)};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Refresh_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Refresh_out[] = {NULL};
static const GDBusMethodInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_method_info_Refresh = {-1, "Refresh", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Refresh_in), (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Refresh_out)};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Start_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Start_out[] = {NULL};
static const GDBusMethodInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_method_info_Start = {-1, "Start", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Start_in), (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Start_out)};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Stop_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Stop_out[] = {NULL};
static const GDBusMethodInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_method_info_Stop = {-1, "Stop", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Stop_in), (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_Stop_out)};
static const GDBusMethodInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_method_info[] = {&_libsocialweb_test_libsocialweb_contact_view_test_dbus_method_info_Close, &_libsocialweb_test_libsocialweb_contact_view_test_dbus_method_info_Refresh, &_libsocialweb_test_libsocialweb_contact_view_test_dbus_method_info_Start, &_libsocialweb_test_libsocialweb_contact_view_test_dbus_method_info_Stop, NULL};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_added_contacts = {-1, "contacts", "a(ssxa{sas})"};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_added[] = {&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_added_contacts, NULL};
static const GDBusSignalInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_signal_info_contacts_added = {-1, "ContactsAdded", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_added)};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_changed_contacts = {-1, "contacts", "a(ssxa{sas})"};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_changed[] = {&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_changed_contacts, NULL};
static const GDBusSignalInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_signal_info_contacts_changed = {-1, "ContactsChanged", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_changed)};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_removed_contacts = {-1, "contacts", "a(ss)"};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_removed[] = {&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_removed_contacts, NULL};
static const GDBusSignalInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_signal_info_contacts_removed = {-1, "ContactsRemoved", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_arg_info_contacts_removed)};
static const GDBusSignalInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_signal_info[] = {&_libsocialweb_test_libsocialweb_contact_view_test_dbus_signal_info_contacts_added, &_libsocialweb_test_libsocialweb_contact_view_test_dbus_signal_info_contacts_changed, &_libsocialweb_test_libsocialweb_contact_view_test_dbus_signal_info_contacts_removed, NULL};
static const GDBusPropertyInfo * const _libsocialweb_test_libsocialweb_contact_view_test_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_info = {-1, "org.gnome.libsocialweb.ContactView", (GDBusMethodInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_method_info), (GDBusSignalInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_signal_info), (GDBusPropertyInfo **) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_property_info)};
static const GDBusInterfaceVTable _libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_vtable = {libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_method_call, libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_get_property, libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_set_property};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_service_capabilities_test_dbus_arg_info_GetStaticCapabilities_result = {-1, "result", "as"};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_service_capabilities_test_dbus_arg_info_GetStaticCapabilities_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_service_capabilities_test_dbus_arg_info_GetStaticCapabilities_out[] = {&_libsocialweb_test_libsocialweb_service_capabilities_test_dbus_arg_info_GetStaticCapabilities_result, NULL};
static const GDBusMethodInfo _libsocialweb_test_libsocialweb_service_capabilities_test_dbus_method_info_GetStaticCapabilities = {-1, "GetStaticCapabilities", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_service_capabilities_test_dbus_arg_info_GetStaticCapabilities_in), (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_service_capabilities_test_dbus_arg_info_GetStaticCapabilities_out)};
static const GDBusMethodInfo * const _libsocialweb_test_libsocialweb_service_capabilities_test_dbus_method_info[] = {&_libsocialweb_test_libsocialweb_service_capabilities_test_dbus_method_info_GetStaticCapabilities, NULL};
static const GDBusSignalInfo * const _libsocialweb_test_libsocialweb_service_capabilities_test_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo * const _libsocialweb_test_libsocialweb_service_capabilities_test_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_info = {-1, "org.gnome.libsocialweb.Service", (GDBusMethodInfo **) (&_libsocialweb_test_libsocialweb_service_capabilities_test_dbus_method_info), (GDBusSignalInfo **) (&_libsocialweb_test_libsocialweb_service_capabilities_test_dbus_signal_info), (GDBusPropertyInfo **) (&_libsocialweb_test_libsocialweb_service_capabilities_test_dbus_property_info)};
static const GDBusInterfaceVTable _libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_vtable = {libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_method_call, libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_get_property, libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_set_property};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_service_query_test_dbus_arg_info_OpenView_query = {-1, "query", "s"};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_service_query_test_dbus_arg_info_OpenView_p = {-1, "p", "a{ss}"};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_service_query_test_dbus_arg_info_OpenView_result = {-1, "result", "o"};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_service_query_test_dbus_arg_info_OpenView_in[] = {&_libsocialweb_test_libsocialweb_service_query_test_dbus_arg_info_OpenView_query, &_libsocialweb_test_libsocialweb_service_query_test_dbus_arg_info_OpenView_p, NULL};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_service_query_test_dbus_arg_info_OpenView_out[] = {&_libsocialweb_test_libsocialweb_service_query_test_dbus_arg_info_OpenView_result, NULL};
static const GDBusMethodInfo _libsocialweb_test_libsocialweb_service_query_test_dbus_method_info_OpenView = {-1, "OpenView", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_service_query_test_dbus_arg_info_OpenView_in), (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_service_query_test_dbus_arg_info_OpenView_out)};
static const GDBusMethodInfo * const _libsocialweb_test_libsocialweb_service_query_test_dbus_method_info[] = {&_libsocialweb_test_libsocialweb_service_query_test_dbus_method_info_OpenView, NULL};
static const GDBusSignalInfo * const _libsocialweb_test_libsocialweb_service_query_test_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo * const _libsocialweb_test_libsocialweb_service_query_test_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _libsocialweb_test_libsocialweb_service_query_test_dbus_interface_info = {-1, "org.gnome.libsocialweb.ContactsQuery", (GDBusMethodInfo **) (&_libsocialweb_test_libsocialweb_service_query_test_dbus_method_info), (GDBusSignalInfo **) (&_libsocialweb_test_libsocialweb_service_query_test_dbus_signal_info), (GDBusPropertyInfo **) (&_libsocialweb_test_libsocialweb_service_query_test_dbus_property_info)};
static const GDBusInterfaceVTable _libsocialweb_test_libsocialweb_service_query_test_dbus_interface_vtable = {libsocialweb_test_libsocialweb_service_query_test_dbus_interface_method_call, libsocialweb_test_libsocialweb_service_query_test_dbus_interface_get_property, libsocialweb_test_libsocialweb_service_query_test_dbus_interface_set_property};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_service_test_dbus_arg_info_OpenView_query = {-1, "query", "s"};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_service_test_dbus_arg_info_OpenView_p = {-1, "p", "a{ss}"};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_service_test_dbus_arg_info_OpenView_result = {-1, "result", "o"};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_service_test_dbus_arg_info_OpenView_in[] = {&_libsocialweb_test_libsocialweb_service_test_dbus_arg_info_OpenView_query, &_libsocialweb_test_libsocialweb_service_test_dbus_arg_info_OpenView_p, NULL};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_service_test_dbus_arg_info_OpenView_out[] = {&_libsocialweb_test_libsocialweb_service_test_dbus_arg_info_OpenView_result, NULL};
static const GDBusMethodInfo _libsocialweb_test_libsocialweb_service_test_dbus_method_info_OpenView = {-1, "OpenView", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_service_test_dbus_arg_info_OpenView_in), (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_service_test_dbus_arg_info_OpenView_out)};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_service_test_dbus_arg_info_GetStaticCapabilities_result = {-1, "result", "as"};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_service_test_dbus_arg_info_GetStaticCapabilities_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_service_test_dbus_arg_info_GetStaticCapabilities_out[] = {&_libsocialweb_test_libsocialweb_service_test_dbus_arg_info_GetStaticCapabilities_result, NULL};
static const GDBusMethodInfo _libsocialweb_test_libsocialweb_service_test_dbus_method_info_GetStaticCapabilities = {-1, "GetStaticCapabilities", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_service_test_dbus_arg_info_GetStaticCapabilities_in), (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_service_test_dbus_arg_info_GetStaticCapabilities_out)};
static const GDBusMethodInfo * const _libsocialweb_test_libsocialweb_service_test_dbus_method_info[] = {&_libsocialweb_test_libsocialweb_service_test_dbus_method_info_OpenView, &_libsocialweb_test_libsocialweb_service_test_dbus_method_info_GetStaticCapabilities, NULL};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_service_test_dbus_arg_info_registered_child_id = {-1, "id", "u"};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_service_test_dbus_arg_info_registered_child[] = {&_libsocialweb_test_libsocialweb_service_test_dbus_arg_info_registered_child_id, NULL};
static const GDBusSignalInfo _libsocialweb_test_libsocialweb_service_test_dbus_signal_info_registered_child = {-1, "RegisteredChild", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_service_test_dbus_arg_info_registered_child)};
static const GDBusSignalInfo * const _libsocialweb_test_libsocialweb_service_test_dbus_signal_info[] = {&_libsocialweb_test_libsocialweb_service_test_dbus_signal_info_registered_child, NULL};
static const GDBusPropertyInfo * const _libsocialweb_test_libsocialweb_service_test_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _libsocialweb_test_libsocialweb_service_test_dbus_interface_info = {-1, "org.gnome.libsocialweb.ContactsQuery", (GDBusMethodInfo **) (&_libsocialweb_test_libsocialweb_service_test_dbus_method_info), (GDBusSignalInfo **) (&_libsocialweb_test_libsocialweb_service_test_dbus_signal_info), (GDBusPropertyInfo **) (&_libsocialweb_test_libsocialweb_service_test_dbus_property_info)};
static const GDBusInterfaceVTable _libsocialweb_test_libsocialweb_service_test_dbus_interface_vtable = {libsocialweb_test_libsocialweb_service_test_dbus_interface_method_call, libsocialweb_test_libsocialweb_service_test_dbus_interface_get_property, libsocialweb_test_libsocialweb_service_test_dbus_interface_set_property};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_server_test_dbus_arg_info_is_online_result = {-1, "result", "b"};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_server_test_dbus_arg_info_is_online_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_server_test_dbus_arg_info_is_online_out[] = {&_libsocialweb_test_libsocialweb_server_test_dbus_arg_info_is_online_result, NULL};
static const GDBusMethodInfo _libsocialweb_test_libsocialweb_server_test_dbus_method_info_is_online = {-1, "IsOnline", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_server_test_dbus_arg_info_is_online_in), (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_server_test_dbus_arg_info_is_online_out)};
static const GDBusArgInfo _libsocialweb_test_libsocialweb_server_test_dbus_arg_info_get_services_result = {-1, "result", "as"};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_server_test_dbus_arg_info_get_services_in[] = {NULL};
static const GDBusArgInfo * const _libsocialweb_test_libsocialweb_server_test_dbus_arg_info_get_services_out[] = {&_libsocialweb_test_libsocialweb_server_test_dbus_arg_info_get_services_result, NULL};
static const GDBusMethodInfo _libsocialweb_test_libsocialweb_server_test_dbus_method_info_get_services = {-1, "GetServices", (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_server_test_dbus_arg_info_get_services_in), (GDBusArgInfo **) (&_libsocialweb_test_libsocialweb_server_test_dbus_arg_info_get_services_out)};
static const GDBusMethodInfo * const _libsocialweb_test_libsocialweb_server_test_dbus_method_info[] = {&_libsocialweb_test_libsocialweb_server_test_dbus_method_info_is_online, &_libsocialweb_test_libsocialweb_server_test_dbus_method_info_get_services, NULL};
static const GDBusSignalInfo * const _libsocialweb_test_libsocialweb_server_test_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo * const _libsocialweb_test_libsocialweb_server_test_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _libsocialweb_test_libsocialweb_server_test_dbus_interface_info = {-1, "org.gnome.libsocialweb", (GDBusMethodInfo **) (&_libsocialweb_test_libsocialweb_server_test_dbus_method_info), (GDBusSignalInfo **) (&_libsocialweb_test_libsocialweb_server_test_dbus_signal_info), (GDBusPropertyInfo **) (&_libsocialweb_test_libsocialweb_server_test_dbus_property_info)};
static const GDBusInterfaceVTable _libsocialweb_test_libsocialweb_server_test_dbus_interface_vtable = {libsocialweb_test_libsocialweb_server_test_dbus_interface_method_call, libsocialweb_test_libsocialweb_server_test_dbus_interface_get_property, libsocialweb_test_libsocialweb_server_test_dbus_interface_set_property};

void libsocialweb_test_contact_view_Close (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	LIBSOCIALWEB_TEST_CONTACT_VIEW_GET_INTERFACE (self)->Close (self, _callback_, _user_data_);
#line 559 "backend.c"
}


void libsocialweb_test_contact_view_Close_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	LIBSOCIALWEB_TEST_CONTACT_VIEW_GET_INTERFACE (self)->Close_finish (self, _res_, error);
#line 566 "backend.c"
}


void libsocialweb_test_contact_view_Refresh (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	LIBSOCIALWEB_TEST_CONTACT_VIEW_GET_INTERFACE (self)->Refresh (self, _callback_, _user_data_);
#line 573 "backend.c"
}


void libsocialweb_test_contact_view_Refresh_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	LIBSOCIALWEB_TEST_CONTACT_VIEW_GET_INTERFACE (self)->Refresh_finish (self, _res_, error);
#line 580 "backend.c"
}


void libsocialweb_test_contact_view_Start (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	LIBSOCIALWEB_TEST_CONTACT_VIEW_GET_INTERFACE (self)->Start (self, _callback_, _user_data_);
#line 587 "backend.c"
}


void libsocialweb_test_contact_view_Start_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	LIBSOCIALWEB_TEST_CONTACT_VIEW_GET_INTERFACE (self)->Start_finish (self, _res_, error);
#line 594 "backend.c"
}


void libsocialweb_test_contact_view_Stop (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	LIBSOCIALWEB_TEST_CONTACT_VIEW_GET_INTERFACE (self)->Stop (self, _callback_, _user_data_);
#line 601 "backend.c"
}


void libsocialweb_test_contact_view_Stop_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	LIBSOCIALWEB_TEST_CONTACT_VIEW_GET_INTERFACE (self)->Stop_finish (self, _res_, error);
#line 608 "backend.c"
}


static void g_cclosure_user_marshal_VOID__POINTER_INT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__POINTER_INT) (gpointer data1, gpointer arg_1, gint arg_2, gpointer data2);
	register GMarshalFunc_VOID__POINTER_INT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (n_param_values == 3);
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		data1 = closure->data;
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		data2 = param_values->data[0].v_pointer;
#line 627 "backend.c"
	} else {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		data1 = param_values->data[0].v_pointer;
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		data2 = closure->data;
#line 633 "backend.c"
	}
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	callback = (GMarshalFunc_VOID__POINTER_INT) (marshal_data ? marshal_data : cc->callback);
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	callback (data1, g_value_get_pointer (param_values + 1), g_value_get_int (param_values + 2), data2);
#line 639 "backend.c"
}


static gpointer _g_variant_ref0 (gpointer self) {
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return self ? g_variant_ref (self) : NULL;
#line 646 "backend.c"
}


void libsocialweb_test_contact_view_contacts_added_element_copy (const LibsocialwebTestContactViewContactsAddedElement* self, LibsocialwebTestContactViewContactsAddedElement* dest) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gint64 _tmp4_ = 0LL;
	GVariant* _tmp5_ = NULL;
	GVariant* _tmp6_ = NULL;
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = (*self).service;
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*dest).service);
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).service = _tmp1_;
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = (*self).id;
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*dest).id);
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).id = _tmp3_;
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp4_ = (*self).time;
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).time = _tmp4_;
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp5_ = (*self).attrs;
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp6_ = _g_variant_ref0 (_tmp5_);
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_variant_unref0 ((*dest).attrs);
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).attrs = _tmp6_;
#line 686 "backend.c"
}


void libsocialweb_test_contact_view_contacts_added_element_destroy (LibsocialwebTestContactViewContactsAddedElement* self) {
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*self).service);
#line 30 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*self).id);
#line 33 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_variant_unref0 ((*self).attrs);
#line 697 "backend.c"
}


LibsocialwebTestContactViewContactsAddedElement* libsocialweb_test_contact_view_contacts_added_element_dup (const LibsocialwebTestContactViewContactsAddedElement* self) {
	LibsocialwebTestContactViewContactsAddedElement* dup;
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	dup = g_new0 (LibsocialwebTestContactViewContactsAddedElement, 1);
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_contact_view_contacts_added_element_copy (self, dup);
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return dup;
#line 709 "backend.c"
}


void libsocialweb_test_contact_view_contacts_added_element_free (LibsocialwebTestContactViewContactsAddedElement* self) {
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_contact_view_contacts_added_element_destroy (self);
#line 27 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_free (self);
#line 718 "backend.c"
}


GType libsocialweb_test_contact_view_contacts_added_element_get_type (void) {
	static volatile gsize libsocialweb_test_contact_view_contacts_added_element_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_contact_view_contacts_added_element_type_id__volatile)) {
		GType libsocialweb_test_contact_view_contacts_added_element_type_id;
		libsocialweb_test_contact_view_contacts_added_element_type_id = g_boxed_type_register_static ("LibsocialwebTestContactViewContactsAddedElement", (GBoxedCopyFunc) libsocialweb_test_contact_view_contacts_added_element_dup, (GBoxedFreeFunc) libsocialweb_test_contact_view_contacts_added_element_free);
		g_once_init_leave (&libsocialweb_test_contact_view_contacts_added_element_type_id__volatile, libsocialweb_test_contact_view_contacts_added_element_type_id);
	}
	return libsocialweb_test_contact_view_contacts_added_element_type_id__volatile;
}


void libsocialweb_test_contact_view_contacts_removed_element_copy (const LibsocialwebTestContactViewContactsRemovedElement* self, LibsocialwebTestContactViewContactsRemovedElement* dest) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = (*self).service;
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*dest).service);
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).service = _tmp1_;
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = (*self).id;
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*dest).id);
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).id = _tmp3_;
#line 754 "backend.c"
}


void libsocialweb_test_contact_view_contacts_removed_element_destroy (LibsocialwebTestContactViewContactsRemovedElement* self) {
#line 38 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*self).service);
#line 39 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*self).id);
#line 763 "backend.c"
}


LibsocialwebTestContactViewContactsRemovedElement* libsocialweb_test_contact_view_contacts_removed_element_dup (const LibsocialwebTestContactViewContactsRemovedElement* self) {
	LibsocialwebTestContactViewContactsRemovedElement* dup;
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	dup = g_new0 (LibsocialwebTestContactViewContactsRemovedElement, 1);
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_contact_view_contacts_removed_element_copy (self, dup);
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return dup;
#line 775 "backend.c"
}


void libsocialweb_test_contact_view_contacts_removed_element_free (LibsocialwebTestContactViewContactsRemovedElement* self) {
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_contact_view_contacts_removed_element_destroy (self);
#line 36 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_free (self);
#line 784 "backend.c"
}


GType libsocialweb_test_contact_view_contacts_removed_element_get_type (void) {
	static volatile gsize libsocialweb_test_contact_view_contacts_removed_element_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_contact_view_contacts_removed_element_type_id__volatile)) {
		GType libsocialweb_test_contact_view_contacts_removed_element_type_id;
		libsocialweb_test_contact_view_contacts_removed_element_type_id = g_boxed_type_register_static ("LibsocialwebTestContactViewContactsRemovedElement", (GBoxedCopyFunc) libsocialweb_test_contact_view_contacts_removed_element_dup, (GBoxedFreeFunc) libsocialweb_test_contact_view_contacts_removed_element_free);
		g_once_init_leave (&libsocialweb_test_contact_view_contacts_removed_element_type_id__volatile, libsocialweb_test_contact_view_contacts_removed_element_type_id);
	}
	return libsocialweb_test_contact_view_contacts_removed_element_type_id__volatile;
}


static void libsocialweb_test_contact_view_base_init (LibsocialwebTestContactViewIface * iface) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	static gboolean initialized = FALSE;
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (!initialized) {
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		initialized = TRUE;
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_signal_new ("contacts_added", LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__POINTER_INT, G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_INT);
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_signal_new ("contacts_changed", LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__POINTER_INT, G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_INT);
#line 25 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_signal_new ("contacts_removed", LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__POINTER_INT, G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_INT);
#line 812 "backend.c"
	}
}


GType libsocialweb_test_contact_view_get_type (void) {
	static volatile gsize libsocialweb_test_contact_view_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_contact_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibsocialwebTestContactViewIface), (GBaseInitFunc) libsocialweb_test_contact_view_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType libsocialweb_test_contact_view_type_id;
		libsocialweb_test_contact_view_type_id = g_type_register_static (G_TYPE_INTERFACE, "LibsocialwebTestContactView", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (libsocialweb_test_contact_view_type_id, G_TYPE_DBUS_PROXY);
		g_type_set_qdata (libsocialweb_test_contact_view_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) libsocialweb_test_contact_view_proxy_get_type);
		g_type_set_qdata (libsocialweb_test_contact_view_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.gnome.libsocialweb.ContactView");
		g_type_set_qdata (libsocialweb_test_contact_view_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) libsocialweb_test_contact_view_register_object);
		g_once_init_leave (&libsocialweb_test_contact_view_type_id__volatile, libsocialweb_test_contact_view_type_id);
	}
	return libsocialweb_test_contact_view_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (LibsocialwebTestContactViewProxy, libsocialweb_test_contact_view_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW, libsocialweb_test_contact_view_proxy_libsocialweb_test_contact_view_interface_init) )
static void libsocialweb_test_contact_view_proxy_class_init (LibsocialwebTestContactViewProxyClass* klass) {
	G_DBUS_PROXY_CLASS (klass)->g_signal = libsocialweb_test_contact_view_proxy_g_signal;
}


static void _vala_LibsocialwebTestContactViewContactsAddedElement_array_free (LibsocialwebTestContactViewContactsAddedElement* array, gint array_length) {
	if (array != NULL) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			libsocialweb_test_contact_view_contacts_added_element_destroy (&array[i]);
		}
	}
	g_free (array);
}


static void _dbus_handle_libsocialweb_test_contact_view_contacts_added (LibsocialwebTestContactView* self, GVariant* parameters) {
	GVariantIter _arguments_iter;
	LibsocialwebTestContactViewContactsAddedElement* contacts = NULL;
	int contacts_length1;
	GVariant* _tmp0_;
	LibsocialwebTestContactViewContactsAddedElement* _tmp1_;
	int _tmp1__length;
	int _tmp1__size;
	int _tmp1__length1;
	GVariantIter _tmp2_;
	GVariant* _tmp3_;
	g_variant_iter_init (&_arguments_iter, parameters);
	contacts_length1 = 0;
	_tmp0_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp1_ = g_new (LibsocialwebTestContactViewContactsAddedElement, 5);
	_tmp1__length = 0;
	_tmp1__size = 4;
	_tmp1__length1 = 0;
	g_variant_iter_init (&_tmp2_, _tmp0_);
	for (; (_tmp3_ = g_variant_iter_next_value (&_tmp2_)) != NULL; _tmp1__length1++) {
		LibsocialwebTestContactViewContactsAddedElement _tmp4_;
		GVariantIter _tmp5_;
		GVariant* _tmp6_;
		GVariant* _tmp7_;
		GVariant* _tmp8_;
		if (_tmp1__size == _tmp1__length) {
			_tmp1__size = 2 * _tmp1__size;
			_tmp1_ = g_renew (LibsocialwebTestContactViewContactsAddedElement, _tmp1_, _tmp1__size + 1);
		}
		g_variant_iter_init (&_tmp5_, _tmp3_);
		_tmp6_ = g_variant_iter_next_value (&_tmp5_);
		_tmp4_.service = g_variant_dup_string (_tmp6_, NULL);
		g_variant_unref (_tmp6_);
		_tmp7_ = g_variant_iter_next_value (&_tmp5_);
		_tmp4_.id = g_variant_dup_string (_tmp7_, NULL);
		g_variant_unref (_tmp7_);
		_tmp8_ = g_variant_iter_next_value (&_tmp5_);
		_tmp4_.time = g_variant_get_int64 (_tmp8_);
		g_variant_unref (_tmp8_);
		_tmp4_.attrs = g_variant_iter_next_value (&_tmp5_);
		_tmp1_[_tmp1__length++] = _tmp4_;
		g_variant_unref (_tmp3_);
	}
	contacts_length1 = _tmp1__length1;
	contacts = _tmp1_;
	g_variant_unref (_tmp0_);
	g_signal_emit_by_name (self, "contacts-added", contacts, contacts_length1);
	contacts = (_vala_LibsocialwebTestContactViewContactsAddedElement_array_free (contacts, contacts_length1), NULL);
}


static void _dbus_handle_libsocialweb_test_contact_view_contacts_changed (LibsocialwebTestContactView* self, GVariant* parameters) {
	GVariantIter _arguments_iter;
	LibsocialwebTestContactViewContactsAddedElement* contacts = NULL;
	int contacts_length1;
	GVariant* _tmp9_;
	LibsocialwebTestContactViewContactsAddedElement* _tmp10_;
	int _tmp10__length;
	int _tmp10__size;
	int _tmp10__length1;
	GVariantIter _tmp11_;
	GVariant* _tmp12_;
	g_variant_iter_init (&_arguments_iter, parameters);
	contacts_length1 = 0;
	_tmp9_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp10_ = g_new (LibsocialwebTestContactViewContactsAddedElement, 5);
	_tmp10__length = 0;
	_tmp10__size = 4;
	_tmp10__length1 = 0;
	g_variant_iter_init (&_tmp11_, _tmp9_);
	for (; (_tmp12_ = g_variant_iter_next_value (&_tmp11_)) != NULL; _tmp10__length1++) {
		LibsocialwebTestContactViewContactsAddedElement _tmp13_;
		GVariantIter _tmp14_;
		GVariant* _tmp15_;
		GVariant* _tmp16_;
		GVariant* _tmp17_;
		if (_tmp10__size == _tmp10__length) {
			_tmp10__size = 2 * _tmp10__size;
			_tmp10_ = g_renew (LibsocialwebTestContactViewContactsAddedElement, _tmp10_, _tmp10__size + 1);
		}
		g_variant_iter_init (&_tmp14_, _tmp12_);
		_tmp15_ = g_variant_iter_next_value (&_tmp14_);
		_tmp13_.service = g_variant_dup_string (_tmp15_, NULL);
		g_variant_unref (_tmp15_);
		_tmp16_ = g_variant_iter_next_value (&_tmp14_);
		_tmp13_.id = g_variant_dup_string (_tmp16_, NULL);
		g_variant_unref (_tmp16_);
		_tmp17_ = g_variant_iter_next_value (&_tmp14_);
		_tmp13_.time = g_variant_get_int64 (_tmp17_);
		g_variant_unref (_tmp17_);
		_tmp13_.attrs = g_variant_iter_next_value (&_tmp14_);
		_tmp10_[_tmp10__length++] = _tmp13_;
		g_variant_unref (_tmp12_);
	}
	contacts_length1 = _tmp10__length1;
	contacts = _tmp10_;
	g_variant_unref (_tmp9_);
	g_signal_emit_by_name (self, "contacts-changed", contacts, contacts_length1);
	contacts = (_vala_LibsocialwebTestContactViewContactsAddedElement_array_free (contacts, contacts_length1), NULL);
}


static void _vala_LibsocialwebTestContactViewContactsRemovedElement_array_free (LibsocialwebTestContactViewContactsRemovedElement* array, gint array_length) {
	if (array != NULL) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			libsocialweb_test_contact_view_contacts_removed_element_destroy (&array[i]);
		}
	}
	g_free (array);
}


static void _dbus_handle_libsocialweb_test_contact_view_contacts_removed (LibsocialwebTestContactView* self, GVariant* parameters) {
	GVariantIter _arguments_iter;
	LibsocialwebTestContactViewContactsRemovedElement* contacts = NULL;
	int contacts_length1;
	GVariant* _tmp18_;
	LibsocialwebTestContactViewContactsRemovedElement* _tmp19_;
	int _tmp19__length;
	int _tmp19__size;
	int _tmp19__length1;
	GVariantIter _tmp20_;
	GVariant* _tmp21_;
	g_variant_iter_init (&_arguments_iter, parameters);
	contacts_length1 = 0;
	_tmp18_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp19_ = g_new (LibsocialwebTestContactViewContactsRemovedElement, 5);
	_tmp19__length = 0;
	_tmp19__size = 4;
	_tmp19__length1 = 0;
	g_variant_iter_init (&_tmp20_, _tmp18_);
	for (; (_tmp21_ = g_variant_iter_next_value (&_tmp20_)) != NULL; _tmp19__length1++) {
		LibsocialwebTestContactViewContactsRemovedElement _tmp22_;
		GVariantIter _tmp23_;
		GVariant* _tmp24_;
		GVariant* _tmp25_;
		if (_tmp19__size == _tmp19__length) {
			_tmp19__size = 2 * _tmp19__size;
			_tmp19_ = g_renew (LibsocialwebTestContactViewContactsRemovedElement, _tmp19_, _tmp19__size + 1);
		}
		g_variant_iter_init (&_tmp23_, _tmp21_);
		_tmp24_ = g_variant_iter_next_value (&_tmp23_);
		_tmp22_.service = g_variant_dup_string (_tmp24_, NULL);
		g_variant_unref (_tmp24_);
		_tmp25_ = g_variant_iter_next_value (&_tmp23_);
		_tmp22_.id = g_variant_dup_string (_tmp25_, NULL);
		g_variant_unref (_tmp25_);
		_tmp19_[_tmp19__length++] = _tmp22_;
		g_variant_unref (_tmp21_);
	}
	contacts_length1 = _tmp19__length1;
	contacts = _tmp19_;
	g_variant_unref (_tmp18_);
	g_signal_emit_by_name (self, "contacts-removed", contacts, contacts_length1);
	contacts = (_vala_LibsocialwebTestContactViewContactsRemovedElement_array_free (contacts, contacts_length1), NULL);
}


static void libsocialweb_test_contact_view_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
	if (strcmp (signal_name, "ContactsAdded") == 0) {
		_dbus_handle_libsocialweb_test_contact_view_contacts_added ((LibsocialwebTestContactView*) proxy, parameters);
	} else if (strcmp (signal_name, "ContactsChanged") == 0) {
		_dbus_handle_libsocialweb_test_contact_view_contacts_changed ((LibsocialwebTestContactView*) proxy, parameters);
	} else if (strcmp (signal_name, "ContactsRemoved") == 0) {
		_dbus_handle_libsocialweb_test_contact_view_contacts_removed ((LibsocialwebTestContactView*) proxy, parameters);
	}
}


static void libsocialweb_test_contact_view_proxy_init (LibsocialwebTestContactViewProxy* self) {
}


static void _vala_g_async_ready_callback (GObject *source_object, GAsyncResult *res, void *user_data) {
	g_simple_async_result_set_op_res_gpointer (user_data, g_object_ref (res), g_object_unref);
	g_simple_async_result_complete (user_data);
	g_object_unref (user_data);
}


static void libsocialweb_test_contact_view_proxy_Close_async (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.libsocialweb.ContactView", "Close");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_simple_async_result_new ((GObject *) self, _callback_, _user_data_, NULL));
	g_object_unref (_message);
}


static void libsocialweb_test_contact_view_proxy_Close_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error) {
	GDBusMessage *_reply_message;
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), g_simple_async_result_get_op_res_gpointer ((GSimpleAsyncResult *) _res_), error);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}


static void libsocialweb_test_contact_view_proxy_Refresh_async (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.libsocialweb.ContactView", "Refresh");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_simple_async_result_new ((GObject *) self, _callback_, _user_data_, NULL));
	g_object_unref (_message);
}


static void libsocialweb_test_contact_view_proxy_Refresh_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error) {
	GDBusMessage *_reply_message;
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), g_simple_async_result_get_op_res_gpointer ((GSimpleAsyncResult *) _res_), error);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}


static void libsocialweb_test_contact_view_proxy_Start_async (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.libsocialweb.ContactView", "Start");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_simple_async_result_new ((GObject *) self, _callback_, _user_data_, NULL));
	g_object_unref (_message);
}


static void libsocialweb_test_contact_view_proxy_Start_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error) {
	GDBusMessage *_reply_message;
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), g_simple_async_result_get_op_res_gpointer ((GSimpleAsyncResult *) _res_), error);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}


static void libsocialweb_test_contact_view_proxy_Stop_async (LibsocialwebTestContactView* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.libsocialweb.ContactView", "Stop");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_simple_async_result_new ((GObject *) self, _callback_, _user_data_, NULL));
	g_object_unref (_message);
}


static void libsocialweb_test_contact_view_proxy_Stop_finish (LibsocialwebTestContactView* self, GAsyncResult* _res_, GError** error) {
	GDBusMessage *_reply_message;
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), g_simple_async_result_get_op_res_gpointer ((GSimpleAsyncResult *) _res_), error);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}


static void libsocialweb_test_contact_view_proxy_libsocialweb_test_contact_view_interface_init (LibsocialwebTestContactViewIface* iface) {
	iface->Close = libsocialweb_test_contact_view_proxy_Close_async;
	iface->Close_finish = libsocialweb_test_contact_view_proxy_Close_finish;
	iface->Refresh = libsocialweb_test_contact_view_proxy_Refresh_async;
	iface->Refresh_finish = libsocialweb_test_contact_view_proxy_Refresh_finish;
	iface->Start = libsocialweb_test_contact_view_proxy_Start_async;
	iface->Start_finish = libsocialweb_test_contact_view_proxy_Start_finish;
	iface->Stop = libsocialweb_test_contact_view_proxy_Stop_async;
	iface->Stop_finish = libsocialweb_test_contact_view_proxy_Stop_finish;
}


static void _dbus_libsocialweb_test_contact_view_Close (LibsocialwebTestContactView* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	libsocialweb_test_contact_view_Close (self, (GAsyncReadyCallback) _dbus_libsocialweb_test_contact_view_Close_ready, invocation);
}


static void _dbus_libsocialweb_test_contact_view_Close_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_) {
	GDBusMethodInvocation * invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	invocation = _user_data_;
	libsocialweb_test_contact_view_Close_finish ((LibsocialwebTestContactView*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_libsocialweb_test_contact_view_Refresh (LibsocialwebTestContactView* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	libsocialweb_test_contact_view_Refresh (self, (GAsyncReadyCallback) _dbus_libsocialweb_test_contact_view_Refresh_ready, invocation);
}


static void _dbus_libsocialweb_test_contact_view_Refresh_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_) {
	GDBusMethodInvocation * invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	invocation = _user_data_;
	libsocialweb_test_contact_view_Refresh_finish ((LibsocialwebTestContactView*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_libsocialweb_test_contact_view_Start (LibsocialwebTestContactView* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	libsocialweb_test_contact_view_Start (self, (GAsyncReadyCallback) _dbus_libsocialweb_test_contact_view_Start_ready, invocation);
}


static void _dbus_libsocialweb_test_contact_view_Start_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_) {
	GDBusMethodInvocation * invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	invocation = _user_data_;
	libsocialweb_test_contact_view_Start_finish ((LibsocialwebTestContactView*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_libsocialweb_test_contact_view_Stop (LibsocialwebTestContactView* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GVariantIter _arguments_iter;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	libsocialweb_test_contact_view_Stop (self, (GAsyncReadyCallback) _dbus_libsocialweb_test_contact_view_Stop_ready, invocation);
}


static void _dbus_libsocialweb_test_contact_view_Stop_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_) {
	GDBusMethodInvocation * invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	invocation = _user_data_;
	libsocialweb_test_contact_view_Stop_finish ((LibsocialwebTestContactView*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void libsocialweb_test_contact_view_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "Close") == 0) {
		_dbus_libsocialweb_test_contact_view_Close (object, parameters, invocation);
	} else if (strcmp (method_name, "Refresh") == 0) {
		_dbus_libsocialweb_test_contact_view_Refresh (object, parameters, invocation);
	} else if (strcmp (method_name, "Start") == 0) {
		_dbus_libsocialweb_test_contact_view_Start (object, parameters, invocation);
	} else if (strcmp (method_name, "Stop") == 0) {
		_dbus_libsocialweb_test_contact_view_Stop (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}


static GVariant* libsocialweb_test_contact_view_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}


static gboolean libsocialweb_test_contact_view_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}


static void _dbus_libsocialweb_test_contact_view_contacts_added (GObject* _sender, LibsocialwebTestContactViewContactsAddedElement* contacts, int contacts_length1, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	LibsocialwebTestContactViewContactsAddedElement* _tmp26_;
	GVariantBuilder _tmp27_;
	int _tmp28_;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_tmp26_ = contacts;
	g_variant_builder_init (&_tmp27_, G_VARIANT_TYPE ("a(ssxa{sas})"));
	for (_tmp28_ = 0; _tmp28_ < contacts_length1; _tmp28_++) {
		GVariantBuilder _tmp29_;
		g_variant_builder_init (&_tmp29_, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_tmp29_, g_variant_new_string ((*_tmp26_).service));
		g_variant_builder_add_value (&_tmp29_, g_variant_new_string ((*_tmp26_).id));
		g_variant_builder_add_value (&_tmp29_, g_variant_new_int64 ((*_tmp26_).time));
		g_variant_builder_add_value (&_tmp29_, (*_tmp26_).attrs);
		g_variant_builder_add_value (&_tmp27_, g_variant_builder_end (&_tmp29_));
		_tmp26_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp27_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.gnome.libsocialweb.ContactView", "ContactsAdded", _arguments, NULL);
}


static void _dbus_libsocialweb_test_contact_view_contacts_changed (GObject* _sender, LibsocialwebTestContactViewContactsAddedElement* contacts, int contacts_length1, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	LibsocialwebTestContactViewContactsAddedElement* _tmp30_;
	GVariantBuilder _tmp31_;
	int _tmp32_;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_tmp30_ = contacts;
	g_variant_builder_init (&_tmp31_, G_VARIANT_TYPE ("a(ssxa{sas})"));
	for (_tmp32_ = 0; _tmp32_ < contacts_length1; _tmp32_++) {
		GVariantBuilder _tmp33_;
		g_variant_builder_init (&_tmp33_, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_tmp33_, g_variant_new_string ((*_tmp30_).service));
		g_variant_builder_add_value (&_tmp33_, g_variant_new_string ((*_tmp30_).id));
		g_variant_builder_add_value (&_tmp33_, g_variant_new_int64 ((*_tmp30_).time));
		g_variant_builder_add_value (&_tmp33_, (*_tmp30_).attrs);
		g_variant_builder_add_value (&_tmp31_, g_variant_builder_end (&_tmp33_));
		_tmp30_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp31_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.gnome.libsocialweb.ContactView", "ContactsChanged", _arguments, NULL);
}


static void _dbus_libsocialweb_test_contact_view_contacts_removed (GObject* _sender, LibsocialwebTestContactViewContactsRemovedElement* contacts, int contacts_length1, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	LibsocialwebTestContactViewContactsRemovedElement* _tmp34_;
	GVariantBuilder _tmp35_;
	int _tmp36_;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_tmp34_ = contacts;
	g_variant_builder_init (&_tmp35_, G_VARIANT_TYPE ("a(ss)"));
	for (_tmp36_ = 0; _tmp36_ < contacts_length1; _tmp36_++) {
		GVariantBuilder _tmp37_;
		g_variant_builder_init (&_tmp37_, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_tmp37_, g_variant_new_string ((*_tmp34_).service));
		g_variant_builder_add_value (&_tmp37_, g_variant_new_string ((*_tmp34_).id));
		g_variant_builder_add_value (&_tmp35_, g_variant_builder_end (&_tmp37_));
		_tmp34_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp35_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.gnome.libsocialweb.ContactView", "ContactsRemoved", _arguments, NULL);
}


guint libsocialweb_test_contact_view_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_libsocialweb_test_contact_view_dbus_interface_info), &_libsocialweb_test_contact_view_dbus_interface_vtable, data, _libsocialweb_test_contact_view_unregister_object, error);
	if (!result) {
		return 0;
	}
	g_signal_connect (object, "contacts-added", (GCallback) _dbus_libsocialweb_test_contact_view_contacts_added, data);
	g_signal_connect (object, "contacts-changed", (GCallback) _dbus_libsocialweb_test_contact_view_contacts_changed, data);
	g_signal_connect (object, "contacts-removed", (GCallback) _dbus_libsocialweb_test_contact_view_contacts_removed, data);
	return result;
}


static void _libsocialweb_test_contact_view_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_signal_handlers_disconnect_by_func (data[0], _dbus_libsocialweb_test_contact_view_contacts_added, data);
	g_signal_handlers_disconnect_by_func (data[0], _dbus_libsocialweb_test_contact_view_contacts_changed, data);
	g_signal_handlers_disconnect_by_func (data[0], _dbus_libsocialweb_test_contact_view_contacts_removed, data);
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


static gpointer _g_hash_table_ref0 (gpointer self) {
#line 81 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return self ? g_hash_table_ref (self) : NULL;
#line 1427 "backend.c"
}


LibsocialwebTestLibsocialwebContactViewTest* libsocialweb_test_libsocialweb_contact_view_test_construct (GType object_type, const gchar* query, GHashTable* p, const gchar* path) {
	LibsocialwebTestLibsocialwebContactViewTest * self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
	GHashTable* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (query != NULL, NULL);
#line 77 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (p != NULL, NULL);
#line 77 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 77 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self = (LibsocialwebTestLibsocialwebContactViewTest*) g_object_new (object_type, NULL);
#line 80 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = query;
#line 80 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 80 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 (self->query);
#line 80 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->query = _tmp1_;
#line 81 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = p;
#line 81 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3_ = _g_hash_table_ref0 (_tmp2_);
#line 81 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_hash_table_unref0 (self->priv->p);
#line 81 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->p = _tmp3_;
#line 82 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp4_ = path;
#line 82 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 82 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 (self->path);
#line 82 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->path = _tmp5_;
#line 77 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return self;
#line 1473 "backend.c"
}


LibsocialwebTestLibsocialwebContactViewTest* libsocialweb_test_libsocialweb_contact_view_test_new (const gchar* query, GHashTable* p, const gchar* path) {
#line 77 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return libsocialweb_test_libsocialweb_contact_view_test_construct (LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, query, p, path);
#line 1480 "backend.c"
}


void libsocialweb_test_libsocialweb_contact_view_test_Close (LibsocialwebTestLibsocialwebContactViewTest* self) {
#line 85 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 1487 "backend.c"
}


void libsocialweb_test_libsocialweb_contact_view_test_Refresh (LibsocialwebTestLibsocialwebContactViewTest* self) {
#line 89 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 1494 "backend.c"
}


void libsocialweb_test_libsocialweb_contact_view_test_Start (LibsocialwebTestLibsocialwebContactViewTest* self) {
	const gchar* _tmp0_ = NULL;
#line 93 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 95 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_debug ("backend.vala:95: Start() called.");
#line 96 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = self->path;
#line 96 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_emit_by_name (self, "start-called", _tmp0_);
#line 1508 "backend.c"
}


void libsocialweb_test_libsocialweb_contact_view_test_Stop (LibsocialwebTestLibsocialwebContactViewTest* self) {
#line 99 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 1515 "backend.c"
}


void libsocialweb_test_libsocialweb_contact_view_test_EmitContactsAdded (LibsocialwebTestLibsocialwebContactViewTest* self, const gchar* text) {
	GError * _inner_error_ = NULL;
#line 124 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 124 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (text != NULL);
#line 1525 "backend.c"
	{
		GDBusConnection* conn = NULL;
		GDBusConnection* _tmp0_ = NULL;
		GVariant* v = NULL;
		const gchar* _tmp1_ = NULL;
		GVariant* _tmp2_ = NULL;
		GDBusConnection* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		GVariant* _tmp5_ = NULL;
#line 128 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp0_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 128 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		conn = _tmp0_;
#line 128 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 128 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1543 "backend.c"
				goto __catch0_g_io_error;
			}
			goto __catch0_g_error;
		}
#line 129 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp1_ = text;
#line 129 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp2_ = g_variant_new_parsed (_tmp1_, NULL);
#line 129 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_variant_ref_sink (_tmp2_);
#line 129 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		v = _tmp2_;
#line 130 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp3_ = conn;
#line 130 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp4_ = self->path;
#line 130 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp5_ = v;
#line 130 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_dbus_connection_emit_signal (_tmp3_, NULL, _tmp4_, LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_IFACE ".ContactView", "ContactsAdded", _tmp5_, &_inner_error_);
#line 130 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 130 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_variant_unref0 (v);
#line 130 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_object_unref0 (conn);
#line 130 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1572 "backend.c"
				goto __catch0_g_io_error;
			}
			goto __catch0_g_error;
		}
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_variant_unref0 (v);
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_object_unref0 (conn);
#line 1581 "backend.c"
	}
	goto __finally0;
	__catch0_g_io_error:
	{
		GError* e = NULL;
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		e = _inner_error_;
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_inner_error_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_assert_not_reached ();
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_error_free0 (e);
#line 1595 "backend.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		e = _inner_error_;
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_inner_error_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_assert_not_reached ();
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_error_free0 (e);
#line 1609 "backend.c"
	}
	__finally0:
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (_inner_error_ != NULL) {
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_clear_error (&_inner_error_);
#line 126 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		return;
#line 1620 "backend.c"
	}
}


void libsocialweb_test_libsocialweb_contact_view_test_EmitContactsChanged (LibsocialwebTestLibsocialwebContactViewTest* self, const gchar* text) {
	GError * _inner_error_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 144 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (text != NULL);
#line 1631 "backend.c"
	{
		GDBusConnection* conn = NULL;
		GDBusConnection* _tmp0_ = NULL;
		GVariant* v = NULL;
		const gchar* _tmp1_ = NULL;
		GVariant* _tmp2_ = NULL;
		GDBusConnection* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		GVariant* _tmp5_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp0_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 148 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		conn = _tmp0_;
#line 148 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 148 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1649 "backend.c"
				goto __catch1_g_io_error;
			}
			goto __catch1_g_error;
		}
#line 149 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp1_ = text;
#line 149 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp2_ = g_variant_new_parsed (_tmp1_, NULL);
#line 149 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_variant_ref_sink (_tmp2_);
#line 149 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		v = _tmp2_;
#line 150 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp3_ = conn;
#line 150 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp4_ = self->path;
#line 150 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp5_ = v;
#line 150 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_dbus_connection_emit_signal (_tmp3_, NULL, _tmp4_, LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_IFACE ".ContactView", "ContactsChanged", _tmp5_, &_inner_error_);
#line 150 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 150 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_variant_unref0 (v);
#line 150 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_object_unref0 (conn);
#line 150 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1678 "backend.c"
				goto __catch1_g_io_error;
			}
			goto __catch1_g_error;
		}
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_variant_unref0 (v);
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_object_unref0 (conn);
#line 1687 "backend.c"
	}
	goto __finally1;
	__catch1_g_io_error:
	{
		GError* e = NULL;
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		e = _inner_error_;
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_inner_error_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_assert_not_reached ();
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_error_free0 (e);
#line 1701 "backend.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e = NULL;
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		e = _inner_error_;
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_inner_error_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_assert_not_reached ();
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_error_free0 (e);
#line 1715 "backend.c"
	}
	__finally1:
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (_inner_error_ != NULL) {
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_clear_error (&_inner_error_);
#line 146 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		return;
#line 1726 "backend.c"
	}
}


void libsocialweb_test_libsocialweb_contact_view_test_EmitContactsRemoved (LibsocialwebTestLibsocialwebContactViewTest* self, const gchar* text) {
	GError * _inner_error_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 164 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (text != NULL);
#line 1737 "backend.c"
	{
		GDBusConnection* conn = NULL;
		GDBusConnection* _tmp0_ = NULL;
		GVariant* v = NULL;
		const gchar* _tmp1_ = NULL;
		GVariant* _tmp2_ = NULL;
		GDBusConnection* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		GVariant* _tmp5_ = NULL;
#line 168 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp0_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 168 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		conn = _tmp0_;
#line 168 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 168 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1755 "backend.c"
				goto __catch2_g_io_error;
			}
			goto __catch2_g_error;
		}
#line 169 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp1_ = text;
#line 169 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp2_ = g_variant_new_parsed (_tmp1_, NULL);
#line 169 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_variant_ref_sink (_tmp2_);
#line 169 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		v = _tmp2_;
#line 170 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp3_ = conn;
#line 170 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp4_ = self->path;
#line 170 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp5_ = v;
#line 170 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_dbus_connection_emit_signal (_tmp3_, NULL, _tmp4_, LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_IFACE ".ContactView", "ContactsRemoved", _tmp5_, &_inner_error_);
#line 170 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 170 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_variant_unref0 (v);
#line 170 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_object_unref0 (conn);
#line 170 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1784 "backend.c"
				goto __catch2_g_io_error;
			}
			goto __catch2_g_error;
		}
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_variant_unref0 (v);
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_object_unref0 (conn);
#line 1793 "backend.c"
	}
	goto __finally2;
	__catch2_g_io_error:
	{
		GError* e = NULL;
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		e = _inner_error_;
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_inner_error_ = NULL;
#line 176 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_assert_not_reached ();
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_error_free0 (e);
#line 1807 "backend.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e = NULL;
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		e = _inner_error_;
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_inner_error_ = NULL;
#line 180 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_assert_not_reached ();
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_error_free0 (e);
#line 1821 "backend.c"
	}
	__finally2:
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (_inner_error_ != NULL) {
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_clear_error (&_inner_error_);
#line 166 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		return;
#line 1832 "backend.c"
	}
}


void libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_copy (const LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* self, LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* dest) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gint64 _tmp4_ = 0LL;
	GVariant* _tmp5_ = NULL;
	GVariant* _tmp6_ = NULL;
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = (*self).service;
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*dest).service);
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).service = _tmp1_;
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = (*self).id;
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*dest).id);
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).id = _tmp3_;
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp4_ = (*self).time;
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).time = _tmp4_;
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp5_ = (*self).attrs;
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp6_ = _g_variant_ref0 (_tmp5_);
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_variant_unref0 ((*dest).attrs);
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).attrs = _tmp6_;
#line 1873 "backend.c"
}


void libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_destroy (LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* self) {
#line 60 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*self).service);
#line 61 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*self).id);
#line 64 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_variant_unref0 ((*self).attrs);
#line 1884 "backend.c"
}


LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_dup (const LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* self) {
	LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* dup;
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	dup = g_new0 (LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement, 1);
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_copy (self, dup);
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return dup;
#line 1896 "backend.c"
}


void libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_free (LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* self) {
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_destroy (self);
#line 58 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_free (self);
#line 1905 "backend.c"
}


GType libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_get_type (void) {
	static volatile gsize libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_type_id__volatile)) {
		GType libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_type_id;
		libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_type_id = g_boxed_type_register_static ("LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement", (GBoxedCopyFunc) libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_dup, (GBoxedFreeFunc) libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_free);
		g_once_init_leave (&libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_type_id__volatile, libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_type_id);
	}
	return libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_type_id__volatile;
}


void libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_copy (const LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* self, LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* dest) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = (*self).service;
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*dest).service);
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).service = _tmp1_;
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = (*self).id;
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*dest).id);
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*dest).id = _tmp3_;
#line 1941 "backend.c"
}


void libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_destroy (LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* self) {
#line 69 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*self).service);
#line 70 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 ((*self).id);
#line 1950 "backend.c"
}


LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_dup (const LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* self) {
	LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* dup;
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	dup = g_new0 (LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement, 1);
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_copy (self, dup);
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return dup;
#line 1962 "backend.c"
}


void libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_free (LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* self) {
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_destroy (self);
#line 67 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_free (self);
#line 1971 "backend.c"
}


GType libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_get_type (void) {
	static volatile gsize libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_type_id__volatile)) {
		GType libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_type_id;
		libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_type_id = g_boxed_type_register_static ("LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement", (GBoxedCopyFunc) libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_dup, (GBoxedFreeFunc) libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_free);
		g_once_init_leave (&libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_type_id__volatile, libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_type_id);
	}
	return libsocialweb_test_libsocialweb_contact_view_test_contacts_removed_element_type_id__volatile;
}


static void libsocialweb_test_libsocialweb_contact_view_test_class_init (LibsocialwebTestLibsocialwebContactViewTestClass * klass) {
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_libsocialweb_contact_view_test_parent_class = g_type_class_peek_parent (klass);
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_type_class_add_private (klass, sizeof (LibsocialwebTestLibsocialwebContactViewTestPrivate));
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	G_OBJECT_CLASS (klass)->finalize = libsocialweb_test_libsocialweb_contact_view_test_finalize;
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_new ("close_called", LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_new ("refresh_called", LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_new ("start_called", LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_new ("stop_called", LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_new ("contacts_added", LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__POINTER_INT, G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_INT);
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_new ("contacts_changed", LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__POINTER_INT, G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_INT);
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_new ("contacts_removed", LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__POINTER_INT, G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_INT);
#line 2007 "backend.c"
}


static void libsocialweb_test_libsocialweb_contact_view_test_instance_init (LibsocialwebTestLibsocialwebContactViewTest * self) {
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv = LIBSOCIALWEB_TEST_LIBSOCIALWEB_CONTACT_VIEW_TEST_GET_PRIVATE (self);
#line 2014 "backend.c"
}


static void libsocialweb_test_libsocialweb_contact_view_test_finalize (GObject* obj) {
	LibsocialwebTestLibsocialwebContactViewTest * self;
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, LibsocialwebTestLibsocialwebContactViewTest);
#line 73 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 (self->query);
#line 74 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_hash_table_unref0 (self->priv->p);
#line 75 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 (self->path);
#line 56 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	G_OBJECT_CLASS (libsocialweb_test_libsocialweb_contact_view_test_parent_class)->finalize (obj);
#line 2030 "backend.c"
}


GType libsocialweb_test_libsocialweb_contact_view_test_get_type (void) {
	static volatile gsize libsocialweb_test_libsocialweb_contact_view_test_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_libsocialweb_contact_view_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibsocialwebTestLibsocialwebContactViewTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) libsocialweb_test_libsocialweb_contact_view_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibsocialwebTestLibsocialwebContactViewTest), 0, (GInstanceInitFunc) libsocialweb_test_libsocialweb_contact_view_test_instance_init, NULL };
		GType libsocialweb_test_libsocialweb_contact_view_test_type_id;
		libsocialweb_test_libsocialweb_contact_view_test_type_id = g_type_register_static (G_TYPE_OBJECT, "LibsocialwebTestLibsocialwebContactViewTest", &g_define_type_info, 0);
		g_type_set_qdata (libsocialweb_test_libsocialweb_contact_view_test_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) libsocialweb_test_libsocialweb_contact_view_test_register_object);
		g_once_init_leave (&libsocialweb_test_libsocialweb_contact_view_test_type_id__volatile, libsocialweb_test_libsocialweb_contact_view_test_type_id);
	}
	return libsocialweb_test_libsocialweb_contact_view_test_type_id__volatile;
}


static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_Close (LibsocialwebTestLibsocialwebContactViewTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	libsocialweb_test_libsocialweb_contact_view_test_Close (self);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_Refresh (LibsocialwebTestLibsocialwebContactViewTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	libsocialweb_test_libsocialweb_contact_view_test_Refresh (self);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_Start (LibsocialwebTestLibsocialwebContactViewTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	libsocialweb_test_libsocialweb_contact_view_test_Start (self);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_Stop (LibsocialwebTestLibsocialwebContactViewTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	libsocialweb_test_libsocialweb_contact_view_test_Stop (self);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "Close") == 0) {
		_dbus_libsocialweb_test_libsocialweb_contact_view_test_Close (object, parameters, invocation);
	} else if (strcmp (method_name, "Refresh") == 0) {
		_dbus_libsocialweb_test_libsocialweb_contact_view_test_Refresh (object, parameters, invocation);
	} else if (strcmp (method_name, "Start") == 0) {
		_dbus_libsocialweb_test_libsocialweb_contact_view_test_Start (object, parameters, invocation);
	} else if (strcmp (method_name, "Stop") == 0) {
		_dbus_libsocialweb_test_libsocialweb_contact_view_test_Stop (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}


static GVariant* libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}


static gboolean libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}


static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_added (GObject* _sender, LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* contacts, int contacts_length1, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* _tmp38_;
	GVariantBuilder _tmp39_;
	int _tmp40_;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_tmp38_ = contacts;
	g_variant_builder_init (&_tmp39_, G_VARIANT_TYPE ("a(ssxa{sas})"));
	for (_tmp40_ = 0; _tmp40_ < contacts_length1; _tmp40_++) {
		GVariantBuilder _tmp41_;
		g_variant_builder_init (&_tmp41_, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_tmp41_, g_variant_new_string ((*_tmp38_).service));
		g_variant_builder_add_value (&_tmp41_, g_variant_new_string ((*_tmp38_).id));
		g_variant_builder_add_value (&_tmp41_, g_variant_new_int64 ((*_tmp38_).time));
		g_variant_builder_add_value (&_tmp41_, (*_tmp38_).attrs);
		g_variant_builder_add_value (&_tmp39_, g_variant_builder_end (&_tmp41_));
		_tmp38_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp39_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.gnome.libsocialweb.ContactView", "ContactsAdded", _arguments, NULL);
}


static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_changed (GObject* _sender, LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* contacts, int contacts_length1, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* _tmp42_;
	GVariantBuilder _tmp43_;
	int _tmp44_;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_tmp42_ = contacts;
	g_variant_builder_init (&_tmp43_, G_VARIANT_TYPE ("a(ssxa{sas})"));
	for (_tmp44_ = 0; _tmp44_ < contacts_length1; _tmp44_++) {
		GVariantBuilder _tmp45_;
		g_variant_builder_init (&_tmp45_, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_tmp45_, g_variant_new_string ((*_tmp42_).service));
		g_variant_builder_add_value (&_tmp45_, g_variant_new_string ((*_tmp42_).id));
		g_variant_builder_add_value (&_tmp45_, g_variant_new_int64 ((*_tmp42_).time));
		g_variant_builder_add_value (&_tmp45_, (*_tmp42_).attrs);
		g_variant_builder_add_value (&_tmp43_, g_variant_builder_end (&_tmp45_));
		_tmp42_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp43_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.gnome.libsocialweb.ContactView", "ContactsChanged", _arguments, NULL);
}


static void _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_removed (GObject* _sender, LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* contacts, int contacts_length1, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	LibsocialwebTestLibsocialwebContactViewTestContactsRemovedElement* _tmp46_;
	GVariantBuilder _tmp47_;
	int _tmp48_;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_tmp46_ = contacts;
	g_variant_builder_init (&_tmp47_, G_VARIANT_TYPE ("a(ss)"));
	for (_tmp48_ = 0; _tmp48_ < contacts_length1; _tmp48_++) {
		GVariantBuilder _tmp49_;
		g_variant_builder_init (&_tmp49_, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_tmp49_, g_variant_new_string ((*_tmp46_).service));
		g_variant_builder_add_value (&_tmp49_, g_variant_new_string ((*_tmp46_).id));
		g_variant_builder_add_value (&_tmp47_, g_variant_builder_end (&_tmp49_));
		_tmp46_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp47_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.gnome.libsocialweb.ContactView", "ContactsRemoved", _arguments, NULL);
}


guint libsocialweb_test_libsocialweb_contact_view_test_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_info), &_libsocialweb_test_libsocialweb_contact_view_test_dbus_interface_vtable, data, _libsocialweb_test_libsocialweb_contact_view_test_unregister_object, error);
	if (!result) {
		return 0;
	}
	g_signal_connect (object, "contacts-added", (GCallback) _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_added, data);
	g_signal_connect (object, "contacts-changed", (GCallback) _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_changed, data);
	g_signal_connect (object, "contacts-removed", (GCallback) _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_removed, data);
	return result;
}


static void _libsocialweb_test_libsocialweb_contact_view_test_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_signal_handlers_disconnect_by_func (data[0], _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_added, data);
	g_signal_handlers_disconnect_by_func (data[0], _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_changed, data);
	g_signal_handlers_disconnect_by_func (data[0], _dbus_libsocialweb_test_libsocialweb_contact_view_test_contacts_removed, data);
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


gchar** libsocialweb_test_libsocialweb_service_capabilities_test_GetStaticCapabilities (LibsocialwebTestLibsocialwebServiceCapabilitiesTest* self, int* result_length1, GError** error) {
#line 189 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 189 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST_GET_INTERFACE (self)->GetStaticCapabilities (self, result_length1, error);
#line 2277 "backend.c"
}


static void libsocialweb_test_libsocialweb_service_capabilities_test_base_init (LibsocialwebTestLibsocialwebServiceCapabilitiesTestIface * iface) {
#line 186 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	static gboolean initialized = FALSE;
#line 186 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (!initialized) {
#line 186 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		initialized = TRUE;
#line 2288 "backend.c"
	}
}


GType libsocialweb_test_libsocialweb_service_capabilities_test_get_type (void) {
	static volatile gsize libsocialweb_test_libsocialweb_service_capabilities_test_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_libsocialweb_service_capabilities_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibsocialwebTestLibsocialwebServiceCapabilitiesTestIface), (GBaseInitFunc) libsocialweb_test_libsocialweb_service_capabilities_test_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType libsocialweb_test_libsocialweb_service_capabilities_test_type_id;
		libsocialweb_test_libsocialweb_service_capabilities_test_type_id = g_type_register_static (G_TYPE_INTERFACE, "LibsocialwebTestLibsocialwebServiceCapabilitiesTest", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (libsocialweb_test_libsocialweb_service_capabilities_test_type_id, G_TYPE_OBJECT);
		g_type_set_qdata (libsocialweb_test_libsocialweb_service_capabilities_test_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) libsocialweb_test_libsocialweb_service_capabilities_test_proxy_get_type);
		g_type_set_qdata (libsocialweb_test_libsocialweb_service_capabilities_test_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.gnome.libsocialweb.Service");
		g_type_set_qdata (libsocialweb_test_libsocialweb_service_capabilities_test_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) libsocialweb_test_libsocialweb_service_capabilities_test_register_object);
		g_once_init_leave (&libsocialweb_test_libsocialweb_service_capabilities_test_type_id__volatile, libsocialweb_test_libsocialweb_service_capabilities_test_type_id);
	}
	return libsocialweb_test_libsocialweb_service_capabilities_test_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (LibsocialwebTestLibsocialwebServiceCapabilitiesTestProxy, libsocialweb_test_libsocialweb_service_capabilities_test_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST, libsocialweb_test_libsocialweb_service_capabilities_test_proxy_libsocialweb_test_libsocialweb_service_capabilities_test_interface_init) )
static void libsocialweb_test_libsocialweb_service_capabilities_test_proxy_class_init (LibsocialwebTestLibsocialwebServiceCapabilitiesTestProxyClass* klass) {
	G_DBUS_PROXY_CLASS (klass)->g_signal = libsocialweb_test_libsocialweb_service_capabilities_test_proxy_g_signal;
}


static void libsocialweb_test_libsocialweb_service_capabilities_test_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
}


static void libsocialweb_test_libsocialweb_service_capabilities_test_proxy_init (LibsocialwebTestLibsocialwebServiceCapabilitiesTestProxy* self) {
}


static gchar** libsocialweb_test_libsocialweb_service_capabilities_test_proxy_GetStaticCapabilities (LibsocialwebTestLibsocialwebServiceCapabilitiesTest* self, int* result_length1, GError** error) {
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	GVariant *_reply;
	GVariantIter _reply_iter;
	gchar** _result;
	int _result_length1;
	GVariant* _tmp50_;
	gchar** _tmp51_;
	int _tmp51__length;
	int _tmp51__size;
	int _tmp51__length1;
	GVariantIter _tmp52_;
	GVariant* _tmp53_;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.libsocialweb.Service", "GetStaticCapabilities");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return NULL;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return NULL;
	}
	_reply = g_dbus_message_get_body (_reply_message);
	g_variant_iter_init (&_reply_iter, _reply);
	_result_length1 = 0;
	_tmp50_ = g_variant_iter_next_value (&_reply_iter);
	_tmp51_ = g_new (gchar*, 5);
	_tmp51__length = 0;
	_tmp51__size = 4;
	_tmp51__length1 = 0;
	g_variant_iter_init (&_tmp52_, _tmp50_);
	for (; (_tmp53_ = g_variant_iter_next_value (&_tmp52_)) != NULL; _tmp51__length1++) {
		if (_tmp51__size == _tmp51__length) {
			_tmp51__size = 2 * _tmp51__size;
			_tmp51_ = g_renew (gchar*, _tmp51_, _tmp51__size + 1);
		}
		_tmp51_[_tmp51__length++] = g_variant_dup_string (_tmp53_, NULL);
		g_variant_unref (_tmp53_);
	}
	_result_length1 = _tmp51__length1;
	_tmp51_[_tmp51__length] = NULL;
	_result = _tmp51_;
	g_variant_unref (_tmp50_);
	*result_length1 = _result_length1;
	g_object_unref (_reply_message);
	return _result;
}


static void libsocialweb_test_libsocialweb_service_capabilities_test_proxy_libsocialweb_test_libsocialweb_service_capabilities_test_interface_init (LibsocialwebTestLibsocialwebServiceCapabilitiesTestIface* iface) {
	iface->GetStaticCapabilities = libsocialweb_test_libsocialweb_service_capabilities_test_proxy_GetStaticCapabilities;
}


static void _dbus_libsocialweb_test_libsocialweb_service_capabilities_test_GetStaticCapabilities (LibsocialwebTestLibsocialwebServiceCapabilitiesTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	gchar** result;
	int result_length1 = 0;
	gchar** _tmp54_;
	GVariantBuilder _tmp55_;
	int _tmp56_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	result = libsocialweb_test_libsocialweb_service_capabilities_test_GetStaticCapabilities (self, &result_length1, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_tmp54_ = result;
	g_variant_builder_init (&_tmp55_, G_VARIANT_TYPE ("as"));
	for (_tmp56_ = 0; _tmp56_ < result_length1; _tmp56_++) {
		g_variant_builder_add_value (&_tmp55_, g_variant_new_string (*_tmp54_));
		_tmp54_++;
	}
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp55_));
	result = (_vala_array_free (result, result_length1, (GDestroyNotify) g_free), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "GetStaticCapabilities") == 0) {
		_dbus_libsocialweb_test_libsocialweb_service_capabilities_test_GetStaticCapabilities (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}


static GVariant* libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}


static gboolean libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}


guint libsocialweb_test_libsocialweb_service_capabilities_test_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_info), &_libsocialweb_test_libsocialweb_service_capabilities_test_dbus_interface_vtable, data, _libsocialweb_test_libsocialweb_service_capabilities_test_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}


static void _libsocialweb_test_libsocialweb_service_capabilities_test_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


char* libsocialweb_test_libsocialweb_service_query_test_OpenView (LibsocialwebTestLibsocialwebServiceQueryTest* self, const gchar* query, GHashTable* p, GError** error) {
#line 196 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 196 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_QUERY_TEST_GET_INTERFACE (self)->OpenView (self, query, p, error);
#line 2481 "backend.c"
}


static void libsocialweb_test_libsocialweb_service_query_test_base_init (LibsocialwebTestLibsocialwebServiceQueryTestIface * iface) {
#line 193 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	static gboolean initialized = FALSE;
#line 193 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (!initialized) {
#line 193 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		initialized = TRUE;
#line 2492 "backend.c"
	}
}


GType libsocialweb_test_libsocialweb_service_query_test_get_type (void) {
	static volatile gsize libsocialweb_test_libsocialweb_service_query_test_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_libsocialweb_service_query_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibsocialwebTestLibsocialwebServiceQueryTestIface), (GBaseInitFunc) libsocialweb_test_libsocialweb_service_query_test_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType libsocialweb_test_libsocialweb_service_query_test_type_id;
		libsocialweb_test_libsocialweb_service_query_test_type_id = g_type_register_static (G_TYPE_INTERFACE, "LibsocialwebTestLibsocialwebServiceQueryTest", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (libsocialweb_test_libsocialweb_service_query_test_type_id, G_TYPE_OBJECT);
		g_type_set_qdata (libsocialweb_test_libsocialweb_service_query_test_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) libsocialweb_test_libsocialweb_service_query_test_proxy_get_type);
		g_type_set_qdata (libsocialweb_test_libsocialweb_service_query_test_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.gnome.libsocialweb.ContactsQuery");
		g_type_set_qdata (libsocialweb_test_libsocialweb_service_query_test_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) libsocialweb_test_libsocialweb_service_query_test_register_object);
		g_once_init_leave (&libsocialweb_test_libsocialweb_service_query_test_type_id__volatile, libsocialweb_test_libsocialweb_service_query_test_type_id);
	}
	return libsocialweb_test_libsocialweb_service_query_test_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (LibsocialwebTestLibsocialwebServiceQueryTestProxy, libsocialweb_test_libsocialweb_service_query_test_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_QUERY_TEST, libsocialweb_test_libsocialweb_service_query_test_proxy_libsocialweb_test_libsocialweb_service_query_test_interface_init) )
static void libsocialweb_test_libsocialweb_service_query_test_proxy_class_init (LibsocialwebTestLibsocialwebServiceQueryTestProxyClass* klass) {
	G_DBUS_PROXY_CLASS (klass)->g_signal = libsocialweb_test_libsocialweb_service_query_test_proxy_g_signal;
}


static void libsocialweb_test_libsocialweb_service_query_test_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
}


static void libsocialweb_test_libsocialweb_service_query_test_proxy_init (LibsocialwebTestLibsocialwebServiceQueryTestProxy* self) {
}


static char* libsocialweb_test_libsocialweb_service_query_test_proxy_OpenView (LibsocialwebTestLibsocialwebServiceQueryTest* self, const gchar* query, GHashTable* p, GError** error) {
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GVariantBuilder _tmp57_;
	GHashTableIter _tmp58_;
	gpointer _tmp59_;
	gpointer _tmp60_;
	GDBusMessage *_reply_message;
	GVariant *_reply;
	GVariantIter _reply_iter;
	char* _result;
	GVariant* _tmp61_;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.libsocialweb.ContactsQuery", "OpenView");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (query));
	g_hash_table_iter_init (&_tmp58_, p);
	g_variant_builder_init (&_tmp57_, G_VARIANT_TYPE ("a{ss}"));
	while (g_hash_table_iter_next (&_tmp58_, &_tmp59_, &_tmp60_)) {
		gchar* _key;
		gchar* _value;
		_key = (gchar*) _tmp59_;
		_value = (gchar*) _tmp60_;
		g_variant_builder_add (&_tmp57_, "{?*}", g_variant_new_string (_key), g_variant_new_string (_value));
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp57_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return NULL;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return NULL;
	}
	_reply = g_dbus_message_get_body (_reply_message);
	g_variant_iter_init (&_reply_iter, _reply);
	_tmp61_ = g_variant_iter_next_value (&_reply_iter);
	_result = g_variant_dup_string (_tmp61_, NULL);
	g_variant_unref (_tmp61_);
	g_object_unref (_reply_message);
	return _result;
}


static void libsocialweb_test_libsocialweb_service_query_test_proxy_libsocialweb_test_libsocialweb_service_query_test_interface_init (LibsocialwebTestLibsocialwebServiceQueryTestIface* iface) {
	iface->OpenView = libsocialweb_test_libsocialweb_service_query_test_proxy_OpenView;
}


static void _dbus_libsocialweb_test_libsocialweb_service_query_test_OpenView (LibsocialwebTestLibsocialwebServiceQueryTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	gchar* query = NULL;
	GVariant* _tmp62_;
	GHashTable* p = NULL;
	GVariant* _tmp63_;
	GHashTable* _tmp64_;
	GVariantIter _tmp65_;
	GVariant* _tmp66_;
	GVariant* _tmp67_;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	char* result;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp62_ = g_variant_iter_next_value (&_arguments_iter);
	query = g_variant_dup_string (_tmp62_, NULL);
	g_variant_unref (_tmp62_);
	_tmp63_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp64_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
	g_variant_iter_init (&_tmp65_, _tmp63_);
	while (g_variant_iter_loop (&_tmp65_, "{?*}", &_tmp66_, &_tmp67_)) {
		g_hash_table_insert (_tmp64_, g_variant_dup_string (_tmp66_, NULL), g_variant_dup_string (_tmp67_, NULL));
	}
	p = _tmp64_;
	g_variant_unref (_tmp63_);
	result = libsocialweb_test_libsocialweb_service_query_test_OpenView (self, query, p, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_reply_builder, g_variant_new_object_path (result));
	_g_free0 (result);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	_g_free0 (query);
	_g_hash_table_unref0 (p);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void libsocialweb_test_libsocialweb_service_query_test_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "OpenView") == 0) {
		_dbus_libsocialweb_test_libsocialweb_service_query_test_OpenView (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}


static GVariant* libsocialweb_test_libsocialweb_service_query_test_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}


static gboolean libsocialweb_test_libsocialweb_service_query_test_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}


guint libsocialweb_test_libsocialweb_service_query_test_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_libsocialweb_test_libsocialweb_service_query_test_dbus_interface_info), &_libsocialweb_test_libsocialweb_service_query_test_dbus_interface_vtable, data, _libsocialweb_test_libsocialweb_service_query_test_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}


static void _libsocialweb_test_libsocialweb_service_query_test_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


LibsocialwebTestLibsocialwebServiceTest* libsocialweb_test_libsocialweb_service_test_construct (GType object_type, const gchar* service_name) {
	LibsocialwebTestLibsocialwebServiceTest * self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GeeHashMap* _tmp2_ = NULL;
#line 210 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (service_name != NULL, NULL);
#line 210 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self = (LibsocialwebTestLibsocialwebServiceTest*) g_object_new (object_type, NULL);
#line 212 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = service_name;
#line 212 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 212 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 (self->priv->service_name);
#line 212 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->service_name = _tmp1_;
#line 213 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_CONTACT_VIEW_TEST, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 213 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_object_unref0 (self->contact_views);
#line 213 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->contact_views = _tmp2_;
#line 210 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return self;
#line 2707 "backend.c"
}


LibsocialwebTestLibsocialwebServiceTest* libsocialweb_test_libsocialweb_service_test_new (const gchar* service_name) {
#line 210 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return libsocialweb_test_libsocialweb_service_test_construct (LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST, service_name);
#line 2714 "backend.c"
}


static char* libsocialweb_test_libsocialweb_service_test_real_OpenView (LibsocialwebTestLibsocialwebServiceQueryTest* base, const gchar* query, GHashTable* p, GError** error) {
	LibsocialwebTestLibsocialwebServiceTest * self;
	char* result = NULL;
	gchar* path = NULL;
	gint _tmp0_ = 0;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp19_ = NULL;
	GHashTable* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	char* _tmp23_ = NULL;
	GError * _inner_error_ = NULL;
#line 219 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self = (LibsocialwebTestLibsocialwebServiceTest*) base;
#line 219 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (query != NULL, NULL);
#line 219 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (p != NULL, NULL);
#line 221 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = libsocialweb_test_libsocialweb_service_test_view_count;
#line 221 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = g_strdup_printf ("%i", _tmp0_);
#line 221 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = _tmp1_;
#line 221 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3_ = g_strconcat (LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_PATH "/View", _tmp2_, NULL);
#line 221 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp4_ = _tmp3_;
#line 221 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 (_tmp2_);
#line 221 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	path = _tmp4_;
#line 2753 "backend.c"
	{
		GDBusConnection* conn = NULL;
		GDBusConnection* _tmp5_ = NULL;
		LibsocialwebTestLibsocialwebContactViewTest* contact_view = NULL;
		const gchar* _tmp6_ = NULL;
		GHashTable* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		LibsocialwebTestLibsocialwebContactViewTest* _tmp9_ = NULL;
		guint _tmp10_ = 0U;
		GDBusConnection* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		LibsocialwebTestLibsocialwebContactViewTest* _tmp13_ = NULL;
		guint _tmp14_ = 0U;
		GeeHashMap* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		LibsocialwebTestLibsocialwebContactViewTest* _tmp17_ = NULL;
		gint _tmp18_ = 0;
#line 225 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp5_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 225 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		conn = _tmp5_;
#line 225 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 225 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 2779 "backend.c"
				goto __catch3_g_io_error;
			}
#line 225 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_free0 (path);
#line 225 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 225 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			g_clear_error (&_inner_error_);
#line 225 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			return NULL;
#line 2790 "backend.c"
		}
#line 226 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp6_ = query;
#line 226 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp7_ = p;
#line 226 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp8_ = path;
#line 226 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp9_ = libsocialweb_test_libsocialweb_contact_view_test_new (_tmp6_, _tmp7_, _tmp8_);
#line 226 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		contact_view = _tmp9_;
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp11_ = conn;
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp12_ = path;
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp13_ = contact_view;
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp14_ = libsocialweb_test_libsocialweb_contact_view_test_register_object (_tmp13_, _tmp11_, _tmp12_, &_inner_error_);
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp10_ = _tmp14_;
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_object_unref0 (contact_view);
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_object_unref0 (conn);
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 2820 "backend.c"
				goto __catch3_g_io_error;
			}
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_object_unref0 (contact_view);
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_object_unref0 (conn);
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			_g_free0 (path);
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			g_clear_error (&_inner_error_);
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			return NULL;
#line 2835 "backend.c"
		}
#line 228 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_signal_emit_by_name (self, "registered-child", _tmp10_);
#line 229 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp15_ = self->contact_views;
#line 229 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp16_ = path;
#line 229 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp17_ = contact_view;
#line 229 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp15_, _tmp16_, _tmp17_);
#line 230 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp18_ = libsocialweb_test_libsocialweb_service_test_view_count;
#line 230 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		libsocialweb_test_libsocialweb_service_test_view_count = _tmp18_ + 1;
#line 223 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_object_unref0 (contact_view);
#line 223 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_object_unref0 (conn);
#line 2855 "backend.c"
	}
	goto __finally3;
	__catch3_g_io_error:
	{
		GError* e = NULL;
#line 223 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		e = _inner_error_;
#line 223 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_inner_error_ = NULL;
#line 234 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_assert_not_reached ();
#line 223 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_error_free0 (e);
#line 2869 "backend.c"
	}
	__finally3:
#line 223 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (_inner_error_ != NULL) {
#line 223 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_free0 (path);
#line 223 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 223 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_clear_error (&_inner_error_);
#line 223 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		return NULL;
#line 2882 "backend.c"
	}
#line 237 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp19_ = query;
#line 237 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp20_ = p;
#line 237 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp21_ = path;
#line 237 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_emit_by_name (self, "open-view-called", _tmp19_, _tmp20_, _tmp21_);
#line 238 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp22_ = path;
#line 238 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp23_ = g_strdup (_tmp22_);
#line 238 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	result = _tmp23_;
#line 238 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 (path);
#line 238 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return result;
#line 2902 "backend.c"
}


static void _vala_array_add1 (gchar*** array, int* length, int* size, gchar* value) {
#line 248 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if ((*length) == (*size)) {
#line 248 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 248 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 2913 "backend.c"
	}
#line 248 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*array)[(*length)++] = value;
#line 248 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*array)[*length] = NULL;
#line 2919 "backend.c"
}


static gchar** libsocialweb_test_libsocialweb_service_test_real_GetStaticCapabilities (LibsocialwebTestLibsocialwebServiceCapabilitiesTest* base, int* result_length1, GError** error) {
	LibsocialwebTestLibsocialwebServiceTest * self;
	gchar** result = NULL;
	gchar** ret = NULL;
	gchar** _tmp0_ = NULL;
	gint ret_length1 = 0;
	gint _ret_size_ = 0;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gchar* _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 245 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self = (LibsocialwebTestLibsocialwebServiceTest*) base;
#line 247 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 247 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	ret = _tmp0_;
#line 247 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	ret_length1 = 0;
#line 247 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_ret_size_ = ret_length1;
#line 248 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = ret;
#line 248 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1__length1 = ret_length1;
#line 248 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = g_strdup ("has-contacts-query-iface");
#line 248 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_vala_array_add1 (&ret, &ret_length1, &_ret_size_, _tmp2_);
#line 249 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3_ = ret;
#line 249 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3__length1 = ret_length1;
#line 249 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (result_length1) {
#line 249 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*result_length1 = _tmp3__length1;
#line 2961 "backend.c"
	}
#line 249 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	result = _tmp3_;
#line 249 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return result;
#line 2967 "backend.c"
}


static void g_cclosure_user_marshal_VOID__STRING_BOXED_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__STRING_BOXED_STRING) (gpointer data1, const char* arg_1, gpointer arg_2, const char* arg_3, gpointer data2);
	register GMarshalFunc_VOID__STRING_BOXED_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (n_param_values == 4);
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		data1 = closure->data;
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		data2 = param_values->data[0].v_pointer;
#line 2986 "backend.c"
	} else {
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		data1 = param_values->data[0].v_pointer;
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		data2 = closure->data;
#line 2992 "backend.c"
	}
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	callback = (GMarshalFunc_VOID__STRING_BOXED_STRING) (marshal_data ? marshal_data : cc->callback);
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	callback (data1, g_value_get_string (param_values + 1), g_value_get_boxed (param_values + 2), g_value_get_string (param_values + 3), data2);
#line 2998 "backend.c"
}


static void libsocialweb_test_libsocialweb_service_test_class_init (LibsocialwebTestLibsocialwebServiceTestClass * klass) {
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_libsocialweb_service_test_parent_class = g_type_class_peek_parent (klass);
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_type_class_add_private (klass, sizeof (LibsocialwebTestLibsocialwebServiceTestPrivate));
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	G_OBJECT_CLASS (klass)->finalize = libsocialweb_test_libsocialweb_service_test_finalize;
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_new ("registered_child", LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__UINT, G_TYPE_NONE, 1, G_TYPE_UINT);
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_new ("open_view_called", LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_BOXED_STRING, G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_HASH_TABLE, G_TYPE_STRING);
#line 3013 "backend.c"
}


static void libsocialweb_test_libsocialweb_service_test_libsocialweb_test_libsocialweb_service_capabilities_test_interface_init (LibsocialwebTestLibsocialwebServiceCapabilitiesTestIface * iface) {
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_libsocialweb_service_test_libsocialweb_test_libsocialweb_service_capabilities_test_parent_iface = g_type_interface_peek_parent (iface);
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	iface->GetStaticCapabilities = (gchar** (*)(LibsocialwebTestLibsocialwebServiceCapabilitiesTest*, int*, GError**)) libsocialweb_test_libsocialweb_service_test_real_GetStaticCapabilities;
#line 3022 "backend.c"
}


static void libsocialweb_test_libsocialweb_service_test_libsocialweb_test_libsocialweb_service_query_test_interface_init (LibsocialwebTestLibsocialwebServiceQueryTestIface * iface) {
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_libsocialweb_service_test_libsocialweb_test_libsocialweb_service_query_test_parent_iface = g_type_interface_peek_parent (iface);
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	iface->OpenView = (char* (*)(LibsocialwebTestLibsocialwebServiceQueryTest*, const gchar*, GHashTable*, GError**)) libsocialweb_test_libsocialweb_service_test_real_OpenView;
#line 3031 "backend.c"
}


static void libsocialweb_test_libsocialweb_service_test_instance_init (LibsocialwebTestLibsocialwebServiceTest * self) {
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv = LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVICE_TEST_GET_PRIVATE (self);
#line 3038 "backend.c"
}


static void libsocialweb_test_libsocialweb_service_test_finalize (GObject* obj) {
	LibsocialwebTestLibsocialwebServiceTest * self;
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_TEST, LibsocialwebTestLibsocialwebServiceTest);
#line 206 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_free0 (self->priv->service_name);
#line 207 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_object_unref0 (self->contact_views);
#line 201 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	G_OBJECT_CLASS (libsocialweb_test_libsocialweb_service_test_parent_class)->finalize (obj);
#line 3052 "backend.c"
}


GType libsocialweb_test_libsocialweb_service_test_get_type (void) {
	static volatile gsize libsocialweb_test_libsocialweb_service_test_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_libsocialweb_service_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibsocialwebTestLibsocialwebServiceTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) libsocialweb_test_libsocialweb_service_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibsocialwebTestLibsocialwebServiceTest), 0, (GInstanceInitFunc) libsocialweb_test_libsocialweb_service_test_instance_init, NULL };
		static const GInterfaceInfo libsocialweb_test_libsocialweb_service_capabilities_test_info = { (GInterfaceInitFunc) libsocialweb_test_libsocialweb_service_test_libsocialweb_test_libsocialweb_service_capabilities_test_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo libsocialweb_test_libsocialweb_service_query_test_info = { (GInterfaceInitFunc) libsocialweb_test_libsocialweb_service_test_libsocialweb_test_libsocialweb_service_query_test_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType libsocialweb_test_libsocialweb_service_test_type_id;
		libsocialweb_test_libsocialweb_service_test_type_id = g_type_register_static (G_TYPE_OBJECT, "LibsocialwebTestLibsocialwebServiceTest", &g_define_type_info, 0);
		g_type_add_interface_static (libsocialweb_test_libsocialweb_service_test_type_id, LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_CAPABILITIES_TEST, &libsocialweb_test_libsocialweb_service_capabilities_test_info);
		g_type_add_interface_static (libsocialweb_test_libsocialweb_service_test_type_id, LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVICE_QUERY_TEST, &libsocialweb_test_libsocialweb_service_query_test_info);
		g_type_set_qdata (libsocialweb_test_libsocialweb_service_test_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) libsocialweb_test_libsocialweb_service_test_register_object);
		g_once_init_leave (&libsocialweb_test_libsocialweb_service_test_type_id__volatile, libsocialweb_test_libsocialweb_service_test_type_id);
	}
	return libsocialweb_test_libsocialweb_service_test_type_id__volatile;
}


static void _dbus_libsocialweb_test_libsocialweb_service_test_OpenView (LibsocialwebTestLibsocialwebServiceTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	gchar* query = NULL;
	GVariant* _tmp68_;
	GHashTable* p = NULL;
	GVariant* _tmp69_;
	GHashTable* _tmp70_;
	GVariantIter _tmp71_;
	GVariant* _tmp72_;
	GVariant* _tmp73_;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	char* result;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp68_ = g_variant_iter_next_value (&_arguments_iter);
	query = g_variant_dup_string (_tmp68_, NULL);
	g_variant_unref (_tmp68_);
	_tmp69_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp70_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
	g_variant_iter_init (&_tmp71_, _tmp69_);
	while (g_variant_iter_loop (&_tmp71_, "{?*}", &_tmp72_, &_tmp73_)) {
		g_hash_table_insert (_tmp70_, g_variant_dup_string (_tmp72_, NULL), g_variant_dup_string (_tmp73_, NULL));
	}
	p = _tmp70_;
	g_variant_unref (_tmp69_);
	result = libsocialweb_test_libsocialweb_service_query_test_OpenView (self, query, p, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_reply_builder, g_variant_new_object_path (result));
	_g_free0 (result);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	_g_free0 (query);
	_g_hash_table_unref0 (p);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_libsocialweb_test_libsocialweb_service_test_GetStaticCapabilities (LibsocialwebTestLibsocialwebServiceTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	gchar** result;
	int result_length1 = 0;
	gchar** _tmp74_;
	GVariantBuilder _tmp75_;
	int _tmp76_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	result = libsocialweb_test_libsocialweb_service_capabilities_test_GetStaticCapabilities (self, &result_length1, &error);
	if (error) {
		g_dbus_method_invocation_return_gerror (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_tmp74_ = result;
	g_variant_builder_init (&_tmp75_, G_VARIANT_TYPE ("as"));
	for (_tmp76_ = 0; _tmp76_ < result_length1; _tmp76_++) {
		g_variant_builder_add_value (&_tmp75_, g_variant_new_string (*_tmp74_));
		_tmp74_++;
	}
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp75_));
	result = (_vala_array_free (result, result_length1, (GDestroyNotify) g_free), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void libsocialweb_test_libsocialweb_service_test_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "OpenView") == 0) {
		_dbus_libsocialweb_test_libsocialweb_service_test_OpenView (object, parameters, invocation);
	} else if (strcmp (method_name, "GetStaticCapabilities") == 0) {
		_dbus_libsocialweb_test_libsocialweb_service_test_GetStaticCapabilities (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}


static GVariant* libsocialweb_test_libsocialweb_service_test_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}


static gboolean libsocialweb_test_libsocialweb_service_test_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}


static void _dbus_libsocialweb_test_libsocialweb_service_test_registered_child (GObject* _sender, guint id, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_uint32 (id));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.gnome.libsocialweb.ContactsQuery", "RegisteredChild", _arguments, NULL);
}


guint libsocialweb_test_libsocialweb_service_test_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_libsocialweb_test_libsocialweb_service_test_dbus_interface_info), &_libsocialweb_test_libsocialweb_service_test_dbus_interface_vtable, data, _libsocialweb_test_libsocialweb_service_test_unregister_object, error);
	if (!result) {
		return 0;
	}
	g_signal_connect (object, "registered-child", (GCallback) _dbus_libsocialweb_test_libsocialweb_service_test_registered_child, data);
	return result;
}


static void _libsocialweb_test_libsocialweb_service_test_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_signal_handlers_disconnect_by_func (data[0], _dbus_libsocialweb_test_libsocialweb_service_test_registered_child, data);
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


static void _g_object_unref0_ (gpointer var) {
#line 268 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 3231 "backend.c"
}


LibsocialwebTestLibsocialwebServerTest* libsocialweb_test_libsocialweb_server_test_construct (GType object_type) {
	LibsocialwebTestLibsocialwebServerTest * self = NULL;
	gchar** _tmp0_ = NULL;
	guint* _tmp1_ = NULL;
	GHashFunc _tmp2_ = NULL;
	GEqualFunc _tmp3_ = NULL;
	GHashTable* _tmp4_ = NULL;
	GError * _inner_error_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self = (LibsocialwebTestLibsocialwebServerTest*) g_object_new (object_type, NULL);
#line 266 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 266 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->services = (_vala_array_free (self->priv->services, self->priv->services_length1, (GDestroyNotify) g_free), NULL);
#line 266 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->services = _tmp0_;
#line 266 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->services_length1 = 0;
#line 266 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_services_size_ = self->priv->services_length1;
#line 267 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = g_new0 (guint, 0);
#line 267 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_registrations = (g_free (self->priv->_registrations), NULL);
#line 267 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_registrations = _tmp1_;
#line 267 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_registrations_length1 = 0;
#line 267 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->__registrations_size_ = self->priv->_registrations_length1;
#line 268 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = g_direct_hash;
#line 268 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3_ = g_direct_equal;
#line 268 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp4_ = g_hash_table_new_full (_tmp2_, _tmp3_, _g_object_unref0_, NULL);
#line 268 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_hash_table_unref0 (self->priv->_register_child_signals);
#line 268 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_register_child_signals = _tmp4_;
#line 3275 "backend.c"
	{
		GDBusConnection* _tmp5_ = NULL;
		GDBusConnection* _tmp6_ = NULL;
		GDBusConnection* _tmp7_ = NULL;
#line 274 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp6_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 274 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp5_ = _tmp6_;
#line 274 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 3286 "backend.c"
			goto __catch4_g_error;
		}
#line 274 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp7_ = _tmp5_;
#line 274 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp5_ = NULL;
#line 274 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_object_unref0 (self->priv->_conn);
#line 274 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		self->priv->_conn = _tmp7_;
#line 272 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_object_unref0 (_tmp5_);
#line 3299 "backend.c"
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		e = _inner_error_;
#line 272 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_inner_error_ = NULL;
#line 278 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp8_ = e->message;
#line 278 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_error ("backend.vala:278: %s", _tmp8_);
#line 272 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_error_free0 (e);
#line 3316 "backend.c"
	}
	__finally4:
#line 272 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (_inner_error_ != NULL) {
#line 272 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 272 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_clear_error (&_inner_error_);
#line 272 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		return NULL;
#line 3327 "backend.c"
	}
#line 264 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return self;
#line 3331 "backend.c"
}


LibsocialwebTestLibsocialwebServerTest* libsocialweb_test_libsocialweb_server_test_new (void) {
#line 264 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return libsocialweb_test_libsocialweb_server_test_construct (LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST);
#line 3338 "backend.c"
}


gboolean libsocialweb_test_libsocialweb_server_test_is_online (LibsocialwebTestLibsocialwebServerTest* self) {
	gboolean result = FALSE;
#line 283 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 285 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	result = TRUE;
#line 285 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return result;
#line 3350 "backend.c"
}


static gchar** _vala_array_dup1 (gchar** self, int length) {
	gchar** result;
	int i;
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	result = g_new0 (gchar*, length + 1);
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	for (i = 0; i < length; i++) {
#line 3361 "backend.c"
		gchar* _tmp0_ = NULL;
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp0_ = g_strdup (self[i]);
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		result[i] = _tmp0_;
#line 3367 "backend.c"
	}
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return result;
#line 3371 "backend.c"
}


gchar** libsocialweb_test_libsocialweb_server_test_get_services (LibsocialwebTestLibsocialwebServerTest* self, int* result_length1) {
	gchar** result = NULL;
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gchar** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 288 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = self->priv->services;
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0__length1 = self->priv->services_length1;
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup1 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1__length1 = _tmp0__length1;
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = _tmp1_;
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2__length1 = _tmp1__length1;
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (result_length1) {
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*result_length1 = _tmp2__length1;
#line 3401 "backend.c"
	}
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	result = _tmp2_;
#line 290 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return result;
#line 3407 "backend.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 300 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return self ? g_object_ref (self) : NULL;
#line 3414 "backend.c"
}


static void _vala_array_add2 (guint** array, int* length, int* size, guint value) {
#line 303 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if ((*length) == (*size)) {
#line 303 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 303 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*array = g_renew (guint, *array, *size);
#line 3425 "backend.c"
	}
#line 303 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*array)[(*length)++] = value;
#line 3429 "backend.c"
}


static void __lambda3_ (LibsocialwebTestLibsocialwebServerTest* self, guint id) {
	guint* _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	guint _tmp1_ = 0U;
#line 303 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = self->priv->_registrations;
#line 303 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0__length1 = self->priv->_registrations_length1;
#line 303 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = id;
#line 303 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_vala_array_add2 (&self->priv->_registrations, &self->priv->_registrations_length1, &self->priv->__registrations_size_, _tmp1_);
#line 3445 "backend.c"
}


static void ___lambda3__libsocialweb_test_libsocialweb_service_test_registered_child (LibsocialwebTestLibsocialwebServiceTest* _sender, guint id, gpointer self) {
#line 300 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	__lambda3_ ((LibsocialwebTestLibsocialwebServerTest*) self, id);
#line 3452 "backend.c"
}


static void _vala_array_add3 (guint** array, int* length, int* size, guint value) {
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if ((*length) == (*size)) {
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*array = g_renew (guint, *array, *size);
#line 3463 "backend.c"
	}
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*array)[(*length)++] = value;
#line 3467 "backend.c"
}


static void _vala_array_add4 (guint** array, int* length, int* size, guint value) {
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if ((*length) == (*size)) {
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*array = g_renew (guint, *array, *size);
#line 3478 "backend.c"
	}
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*array)[(*length)++] = value;
#line 3482 "backend.c"
}


static void _vala_array_add5 (gchar*** array, int* length, int* size, gchar* value) {
#line 321 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if ((*length) == (*size)) {
#line 321 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 321 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 3493 "backend.c"
	}
#line 321 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*array)[(*length)++] = value;
#line 321 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*array)[*length] = NULL;
#line 3499 "backend.c"
}


LibsocialwebTestLibsocialwebServiceTest* libsocialweb_test_libsocialweb_server_test_add_service (LibsocialwebTestLibsocialwebServerTest* self, const gchar* service_name) {
	LibsocialwebTestLibsocialwebServiceTest* result = NULL;
	LibsocialwebTestLibsocialwebServiceTest* service = NULL;
	const gchar* _tmp0_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp3_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp4_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp5_ = NULL;
	gulong _tmp6_ = 0UL;
	gchar** _tmp26_ = NULL;
	gint _tmp26__length1 = 0;
	const gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	GError * _inner_error_ = NULL;
#line 294 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 294 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (service_name != NULL, NULL);
#line 297 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = service_name;
#line 297 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = libsocialweb_test_libsocialweb_service_test_new (_tmp0_);
#line 297 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	service = _tmp1_;
#line 300 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = self->priv->_register_child_signals;
#line 300 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3_ = service;
#line 300 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 300 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp5_ = service;
#line 300 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp6_ = g_signal_connect_object (_tmp5_, "registered-child", (GCallback) ___lambda3__libsocialweb_test_libsocialweb_service_test_registered_child, self, 0);
#line 300 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_hash_table_insert (_tmp2_, _tmp4_, (gpointer) ((guintptr) _tmp6_));
#line 3540 "backend.c"
	{
		guint _tmp7_ = 0U;
		GDBusConnection* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		LibsocialwebTestLibsocialwebServiceTest* _tmp12_ = NULL;
		guint _tmp13_ = 0U;
		guint _tmp14_ = 0U;
		guint* _tmp15_ = NULL;
		gint _tmp15__length1 = 0;
		guint _tmp16_ = 0U;
		GDBusConnection* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		LibsocialwebTestLibsocialwebServiceTest* _tmp21_ = NULL;
		guint _tmp22_ = 0U;
		guint _tmp23_ = 0U;
		guint* _tmp24_ = NULL;
		gint _tmp24__length1 = 0;
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp8_ = self->priv->_conn;
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp9_ = service_name;
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp10_ = g_strconcat (LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_PATH "/Service/", _tmp9_, NULL);
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp11_ = _tmp10_;
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp12_ = service;
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp13_ = libsocialweb_test_libsocialweb_service_capabilities_test_register_object ((LibsocialwebTestLibsocialwebServiceCapabilitiesTest*) _tmp12_, _tmp8_, _tmp11_, &_inner_error_);
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp14_ = _tmp13_;
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_free0 (_tmp11_);
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp7_ = _tmp14_;
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 3582 "backend.c"
			goto __catch5_g_error;
		}
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp15_ = self->priv->_registrations;
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp15__length1 = self->priv->_registrations_length1;
#line 308 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_vala_array_add3 (&self->priv->_registrations, &self->priv->_registrations_length1, &self->priv->__registrations_size_, _tmp7_);
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp17_ = self->priv->_conn;
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp18_ = service_name;
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp19_ = g_strconcat (LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_PATH "/Service/", _tmp18_, NULL);
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp20_ = _tmp19_;
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp21_ = service;
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp22_ = libsocialweb_test_libsocialweb_service_query_test_register_object ((LibsocialwebTestLibsocialwebServiceQueryTest*) _tmp21_, _tmp17_, _tmp20_, &_inner_error_);
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp23_ = _tmp22_;
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_free0 (_tmp20_);
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp16_ = _tmp23_;
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 3611 "backend.c"
			goto __catch5_g_error;
		}
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp24_ = self->priv->_registrations;
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp24__length1 = self->priv->_registrations_length1;
#line 312 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_vala_array_add4 (&self->priv->_registrations, &self->priv->_registrations_length1, &self->priv->__registrations_size_, _tmp16_);
#line 3620 "backend.c"
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp25_ = NULL;
#line 306 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		e = _inner_error_;
#line 306 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_inner_error_ = NULL;
#line 319 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp25_ = e->message;
#line 319 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_error ("backend.vala:319: %s", _tmp25_);
#line 306 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_error_free0 (e);
#line 3637 "backend.c"
	}
	__finally5:
#line 306 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (_inner_error_ != NULL) {
#line 306 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_object_unref0 (service);
#line 306 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 306 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_clear_error (&_inner_error_);
#line 306 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		return NULL;
#line 3650 "backend.c"
	}
#line 321 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp26_ = self->priv->services;
#line 321 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp26__length1 = self->priv->services_length1;
#line 321 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp27_ = service_name;
#line 321 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp28_ = g_strdup (_tmp27_);
#line 321 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_vala_array_add5 (&self->priv->services, &self->priv->services_length1, &self->priv->_services_size_, _tmp28_);
#line 322 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	result = service;
#line 322 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return result;
#line 3666 "backend.c"
}


static void _vala_array_add6 (guint** array, int* length, int* size, guint value) {
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if ((*length) == (*size)) {
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*array = g_renew (guint, *array, *size);
#line 3677 "backend.c"
	}
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	(*array)[(*length)++] = value;
#line 3681 "backend.c"
}


void libsocialweb_test_libsocialweb_server_test_register (LibsocialwebTestLibsocialwebServerTest* self) {
	GError * _inner_error_ = NULL;
#line 326 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 3689 "backend.c"
	{
		guint _tmp0_ = 0U;
		GDBusConnection* _tmp1_ = NULL;
		guint _tmp2_ = 0U;
		guint* _tmp3_ = NULL;
		gint _tmp3__length1 = 0;
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp1_ = self->priv->_conn;
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp2_ = libsocialweb_test_libsocialweb_server_test_register_object (self, _tmp1_, LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_PATH, &_inner_error_);
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp0_ = _tmp2_;
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (_inner_error_ != NULL) {
#line 3704 "backend.c"
			goto __catch6_g_error;
		}
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp3_ = self->priv->_registrations;
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp3__length1 = self->priv->_registrations_length1;
#line 330 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_vala_array_add6 (&self->priv->_registrations, &self->priv->_registrations_length1, &self->priv->__registrations_size_, _tmp0_);
#line 3713 "backend.c"
	}
	goto __finally6;
	__catch6_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp4_ = NULL;
#line 328 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		e = _inner_error_;
#line 328 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_inner_error_ = NULL;
#line 335 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp4_ = e->message;
#line 335 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_error ("backend.vala:335: %s", _tmp4_);
#line 328 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_error_free0 (e);
#line 3730 "backend.c"
	}
	__finally6:
#line 328 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (_inner_error_ != NULL) {
#line 328 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 328 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_clear_error (&_inner_error_);
#line 328 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		return;
#line 3741 "backend.c"
	}
}


void libsocialweb_test_libsocialweb_server_test_unregister (LibsocialwebTestLibsocialwebServerTest* self) {
	guint* _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	GHashTableIter iter = {0};
	GHashTable* _tmp3_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* instance = NULL;
	gulong sig = 0UL;
#line 340 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 342 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = self->priv->_registrations;
#line 342 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0__length1 = self->priv->_registrations_length1;
#line 3759 "backend.c"
	{
		guint* reg_collection = NULL;
		gint reg_collection_length1 = 0;
		gint _reg_collection_size_ = 0;
		gint reg_it = 0;
#line 342 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		reg_collection = _tmp0_;
#line 342 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		reg_collection_length1 = _tmp0__length1;
#line 342 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		for (reg_it = 0; reg_it < _tmp0__length1; reg_it = reg_it + 1) {
#line 3771 "backend.c"
			guint reg = 0U;
#line 342 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			reg = reg_collection[reg_it];
#line 3775 "backend.c"
			{
				GDBusConnection* _tmp1_ = NULL;
				guint _tmp2_ = 0U;
#line 344 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
				_tmp1_ = self->priv->_conn;
#line 344 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
				_tmp2_ = reg;
#line 344 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
				g_dbus_connection_unregister_object (_tmp1_, _tmp2_);
#line 3785 "backend.c"
			}
		}
	}
#line 347 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp3_ = self->priv->_register_child_signals;
#line 347 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_hash_table_iter_init (&iter, _tmp3_);
#line 352 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	while (TRUE) {
#line 3795 "backend.c"
		gconstpointer _tmp4_ = NULL;
		gconstpointer _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		LibsocialwebTestLibsocialwebServiceTest* _tmp7_ = NULL;
		LibsocialwebTestLibsocialwebServiceTest* _tmp8_ = NULL;
		gulong _tmp9_ = 0UL;
#line 352 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp6_ = g_hash_table_iter_next (&iter, (gpointer*) (&_tmp4_), (gpointer*) (&_tmp5_));
#line 352 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_g_object_unref0 (instance);
#line 352 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp7_ = _g_object_ref0 (_tmp4_);
#line 352 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		instance = _tmp7_;
#line 352 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		sig = _tmp5_;
#line 352 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (!_tmp6_) {
#line 352 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			break;
#line 3816 "backend.c"
		}
#line 354 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp8_ = instance;
#line 354 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp9_ = sig;
#line 354 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 355 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_hash_table_iter_remove (&iter);
#line 3826 "backend.c"
	}
#line 340 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_object_unref0 (instance);
#line 3830 "backend.c"
}


static void libsocialweb_test_libsocialweb_server_test_class_init (LibsocialwebTestLibsocialwebServerTestClass * klass) {
#line 254 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_libsocialweb_server_test_parent_class = g_type_class_peek_parent (klass);
#line 254 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_type_class_add_private (klass, sizeof (LibsocialwebTestLibsocialwebServerTestPrivate));
#line 254 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	G_OBJECT_CLASS (klass)->finalize = libsocialweb_test_libsocialweb_server_test_finalize;
#line 3841 "backend.c"
}


static void libsocialweb_test_libsocialweb_server_test_instance_init (LibsocialwebTestLibsocialwebServerTest * self) {
#line 254 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv = LIBSOCIALWEB_TEST_LIBSOCIALWEB_SERVER_TEST_GET_PRIVATE (self);
#line 3848 "backend.c"
}


static void libsocialweb_test_libsocialweb_server_test_finalize (GObject* obj) {
	LibsocialwebTestLibsocialwebServerTest * self;
#line 254 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST, LibsocialwebTestLibsocialwebServerTest);
#line 256 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->services = (_vala_array_free (self->priv->services, self->priv->services_length1, (GDestroyNotify) g_free), NULL);
#line 258 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_object_unref0 (self->priv->_conn);
#line 260 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_registrations = (g_free (self->priv->_registrations), NULL);
#line 262 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_hash_table_unref0 (self->priv->_register_child_signals);
#line 254 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	G_OBJECT_CLASS (libsocialweb_test_libsocialweb_server_test_parent_class)->finalize (obj);
#line 3866 "backend.c"
}


GType libsocialweb_test_libsocialweb_server_test_get_type (void) {
	static volatile gsize libsocialweb_test_libsocialweb_server_test_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_libsocialweb_server_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibsocialwebTestLibsocialwebServerTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) libsocialweb_test_libsocialweb_server_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibsocialwebTestLibsocialwebServerTest), 0, (GInstanceInitFunc) libsocialweb_test_libsocialweb_server_test_instance_init, NULL };
		GType libsocialweb_test_libsocialweb_server_test_type_id;
		libsocialweb_test_libsocialweb_server_test_type_id = g_type_register_static (G_TYPE_OBJECT, "LibsocialwebTestLibsocialwebServerTest", &g_define_type_info, 0);
		g_type_set_qdata (libsocialweb_test_libsocialweb_server_test_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) libsocialweb_test_libsocialweb_server_test_register_object);
		g_once_init_leave (&libsocialweb_test_libsocialweb_server_test_type_id__volatile, libsocialweb_test_libsocialweb_server_test_type_id);
	}
	return libsocialweb_test_libsocialweb_server_test_type_id__volatile;
}


static void _dbus_libsocialweb_test_libsocialweb_server_test_is_online (LibsocialwebTestLibsocialwebServerTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	gboolean result;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	result = libsocialweb_test_libsocialweb_server_test_is_online (self);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_reply_builder, g_variant_new_boolean (result));
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_libsocialweb_test_libsocialweb_server_test_get_services (LibsocialwebTestLibsocialwebServerTest* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	gchar** result;
	int result_length1 = 0;
	gchar** _tmp77_;
	GVariantBuilder _tmp78_;
	int _tmp79_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	result = libsocialweb_test_libsocialweb_server_test_get_services (self, &result_length1);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_tmp77_ = result;
	g_variant_builder_init (&_tmp78_, G_VARIANT_TYPE ("as"));
	for (_tmp79_ = 0; _tmp79_ < result_length1; _tmp79_++) {
		g_variant_builder_add_value (&_tmp78_, g_variant_new_string (*_tmp77_));
		_tmp77_++;
	}
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp78_));
	result = (_vala_array_free (result, result_length1, (GDestroyNotify) g_free), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void libsocialweb_test_libsocialweb_server_test_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "IsOnline") == 0) {
		_dbus_libsocialweb_test_libsocialweb_server_test_is_online (object, parameters, invocation);
	} else if (strcmp (method_name, "GetServices") == 0) {
		_dbus_libsocialweb_test_libsocialweb_server_test_get_services (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}


static GVariant* libsocialweb_test_libsocialweb_server_test_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}


static gboolean libsocialweb_test_libsocialweb_server_test_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}


guint libsocialweb_test_libsocialweb_server_test_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_libsocialweb_test_libsocialweb_server_test_dbus_interface_info), &_libsocialweb_test_libsocialweb_server_test_dbus_interface_vtable, data, _libsocialweb_test_libsocialweb_server_test_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}


static void _libsocialweb_test_libsocialweb_server_test_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


LibsocialwebTestBackend* libsocialweb_test_backend_construct (GType object_type) {
	LibsocialwebTestBackend* self = NULL;
#line 372 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self = (LibsocialwebTestBackend*) g_type_create_instance (object_type);
#line 374 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_backend_set_debug (self, FALSE);
#line 372 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return self;
#line 4000 "backend.c"
}


LibsocialwebTestBackend* libsocialweb_test_backend_new (void) {
#line 372 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return libsocialweb_test_backend_construct (LIBSOCIALWEB_TEST_TYPE_BACKEND);
#line 4007 "backend.c"
}


static void _libsocialweb_test_backend_on_bus_aquired_gbus_acquired_callback (GDBusConnection* connection, const gchar* name, gpointer self) {
#line 382 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_backend_on_bus_aquired ((LibsocialwebTestBackend*) self, connection);
#line 4014 "backend.c"
}


static void __lambda4_ (LibsocialwebTestBackend* self) {
#line 388 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_emit_by_name (self, "ready");
#line 4021 "backend.c"
}


static void ___lambda4__gbus_name_acquired_callback (GDBusConnection* connection, const gchar* name, gpointer self) {
#line 382 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	__lambda4_ ((LibsocialwebTestBackend*) self);
#line 4028 "backend.c"
}


static void __lambda5_ (LibsocialwebTestBackend* self) {
#line 392 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_message ("backend.vala:392: Could not aquire D-Bus name\n");
#line 393 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_assert_not_reached ();
#line 4037 "backend.c"
}


static void ___lambda5__gbus_name_lost_callback (GDBusConnection* connection, const gchar* name, gpointer self) {
#line 382 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	__lambda5_ ((LibsocialwebTestBackend*) self);
#line 4044 "backend.c"
}


void libsocialweb_test_backend_set_up (LibsocialwebTestBackend* self) {
	LibsocialwebTestLibsocialwebServerTest* _tmp0_ = NULL;
	LibsocialwebTestLibsocialwebServerTest* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 377 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 379 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = libsocialweb_test_libsocialweb_server_test_new ();
#line 379 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_object_unref0 (self->priv->_lsw_server);
#line 379 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_lsw_server = _tmp0_;
#line 380 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = self->priv->_lsw_server;
#line 380 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_libsocialweb_server_test_register (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST, LibsocialwebTestLibsocialwebServerTest));
#line 382 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = g_bus_own_name_with_closures (G_BUS_TYPE_SESSION, LIBSOCIALWEB_TEST_BACKEND_LIBSOCIALWEB_BUS_NAME, G_BUS_NAME_OWNER_FLAGS_NONE, (GClosure*) ((_libsocialweb_test_backend_on_bus_aquired_gbus_acquired_callback == NULL) ? NULL : g_cclosure_new ((GCallback) _libsocialweb_test_backend_on_bus_aquired_gbus_acquired_callback, libsocialweb_test_backend_ref (self), libsocialweb_test_backend_unref)), (GClosure*) ((___lambda4__gbus_name_acquired_callback == NULL) ? NULL : g_cclosure_new ((GCallback) ___lambda4__gbus_name_acquired_callback, libsocialweb_test_backend_ref (self), libsocialweb_test_backend_unref)), (GClosure*) ((___lambda5__gbus_name_lost_callback == NULL) ? NULL : g_cclosure_new ((GCallback) ___lambda5__gbus_name_lost_callback, libsocialweb_test_backend_ref (self), libsocialweb_test_backend_unref)));
#line 382 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_name_id = _tmp2_;
#line 4068 "backend.c"
}


static void libsocialweb_test_backend_on_bus_aquired (LibsocialwebTestBackend* self, GDBusConnection* conn) {
#line 397 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 397 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (conn != NULL);
#line 4077 "backend.c"
}


LibsocialwebTestLibsocialwebServiceTest* libsocialweb_test_backend_add_service (LibsocialwebTestBackend* self, const gchar* service_name) {
	LibsocialwebTestLibsocialwebServiceTest* result = NULL;
	LibsocialwebTestLibsocialwebServerTest* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp2_ = NULL;
#line 401 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 401 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (service_name != NULL, NULL);
#line 404 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = self->priv->_lsw_server;
#line 404 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp1_ = service_name;
#line 404 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = libsocialweb_test_libsocialweb_server_test_add_service (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST, LibsocialwebTestLibsocialwebServerTest), _tmp1_);
#line 404 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	result = _tmp2_;
#line 404 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return result;
#line 4100 "backend.c"
}


void libsocialweb_test_backend_tear_down (LibsocialwebTestBackend* self) {
	LibsocialwebTestLibsocialwebServerTest* _tmp0_ = NULL;
	guint _tmp2_ = 0U;
#line 407 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 409 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = self->priv->_lsw_server;
#line 409 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (_tmp0_ != NULL) {
#line 4113 "backend.c"
		LibsocialwebTestLibsocialwebServerTest* _tmp1_ = NULL;
#line 410 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp1_ = self->priv->_lsw_server;
#line 410 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		libsocialweb_test_libsocialweb_server_test_unregister (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, LIBSOCIALWEB_TEST_TYPE_LIBSOCIALWEB_SERVER_TEST, LibsocialwebTestLibsocialwebServerTest));
#line 4119 "backend.c"
	}
#line 412 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_object_unref0 (self->priv->_lsw_server);
#line 412 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_lsw_server = NULL;
#line 414 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp2_ = self->priv->_name_id;
#line 414 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 4129 "backend.c"
		guint _tmp3_ = 0U;
#line 416 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		_tmp3_ = self->priv->_name_id;
#line 416 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_bus_unown_name (_tmp3_);
#line 417 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		self->priv->_name_id = (guint) 0;
#line 4137 "backend.c"
	}
}


gboolean libsocialweb_test_backend_get_debug (LibsocialwebTestBackend* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 366 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 366 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = self->priv->_debug;
#line 366 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	result = _tmp0_;
#line 366 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return result;
#line 4153 "backend.c"
}


void libsocialweb_test_backend_set_debug (LibsocialwebTestBackend* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 366 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (self != NULL);
#line 366 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_tmp0_ = value;
#line 366 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_debug = _tmp0_;
#line 4165 "backend.c"
}


static void libsocialweb_test_value_backend_init (GValue* value) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	value->data[0].v_pointer = NULL;
#line 4172 "backend.c"
}


static void libsocialweb_test_value_backend_free_value (GValue* value) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (value->data[0].v_pointer) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		libsocialweb_test_backend_unref (value->data[0].v_pointer);
#line 4181 "backend.c"
	}
}


static void libsocialweb_test_value_backend_copy_value (const GValue* src_value, GValue* dest_value) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (src_value->data[0].v_pointer) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		dest_value->data[0].v_pointer = libsocialweb_test_backend_ref (src_value->data[0].v_pointer);
#line 4191 "backend.c"
	} else {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		dest_value->data[0].v_pointer = NULL;
#line 4195 "backend.c"
	}
}


static gpointer libsocialweb_test_value_backend_peek_pointer (const GValue* value) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return value->data[0].v_pointer;
#line 4203 "backend.c"
}


static gchar* libsocialweb_test_value_backend_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (collect_values[0].v_pointer) {
#line 4210 "backend.c"
		LibsocialwebTestBackend* object;
		object = collect_values[0].v_pointer;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		if (object->parent_instance.g_class == NULL) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 4217 "backend.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 4221 "backend.c"
		}
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		value->data[0].v_pointer = libsocialweb_test_backend_ref (object);
#line 4225 "backend.c"
	} else {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		value->data[0].v_pointer = NULL;
#line 4229 "backend.c"
	}
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return NULL;
#line 4233 "backend.c"
}


static gchar* libsocialweb_test_value_backend_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	LibsocialwebTestBackend** object_p;
	object_p = collect_values[0].v_pointer;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (!object_p) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 4244 "backend.c"
	}
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (!value->data[0].v_pointer) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*object_p = NULL;
#line 4250 "backend.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*object_p = value->data[0].v_pointer;
#line 4254 "backend.c"
	} else {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		*object_p = libsocialweb_test_backend_ref (value->data[0].v_pointer);
#line 4258 "backend.c"
	}
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return NULL;
#line 4262 "backend.c"
}


GParamSpec* libsocialweb_test_param_spec_backend (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	LibsocialwebTestParamSpecBackend* spec;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (g_type_is_a (object_type, LIBSOCIALWEB_TEST_TYPE_BACKEND), NULL);
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return G_PARAM_SPEC (spec);
#line 4276 "backend.c"
}


gpointer libsocialweb_test_value_get_backend (const GValue* value) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, LIBSOCIALWEB_TEST_TYPE_BACKEND), NULL);
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return value->data[0].v_pointer;
#line 4285 "backend.c"
}


void libsocialweb_test_value_set_backend (GValue* value, gpointer v_object) {
	LibsocialwebTestBackend* old;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, LIBSOCIALWEB_TEST_TYPE_BACKEND));
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	old = value->data[0].v_pointer;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (v_object) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, LIBSOCIALWEB_TEST_TYPE_BACKEND));
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		value->data[0].v_pointer = v_object;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		libsocialweb_test_backend_ref (value->data[0].v_pointer);
#line 4305 "backend.c"
	} else {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		value->data[0].v_pointer = NULL;
#line 4309 "backend.c"
	}
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (old) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		libsocialweb_test_backend_unref (old);
#line 4315 "backend.c"
	}
}


void libsocialweb_test_value_take_backend (GValue* value, gpointer v_object) {
	LibsocialwebTestBackend* old;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, LIBSOCIALWEB_TEST_TYPE_BACKEND));
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	old = value->data[0].v_pointer;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (v_object) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, LIBSOCIALWEB_TEST_TYPE_BACKEND));
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		value->data[0].v_pointer = v_object;
#line 4334 "backend.c"
	} else {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		value->data[0].v_pointer = NULL;
#line 4338 "backend.c"
	}
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (old) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		libsocialweb_test_backend_unref (old);
#line 4344 "backend.c"
	}
}


static void libsocialweb_test_backend_class_init (LibsocialwebTestBackendClass * klass) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	libsocialweb_test_backend_parent_class = g_type_class_peek_parent (klass);
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	LIBSOCIALWEB_TEST_BACKEND_CLASS (klass)->finalize = libsocialweb_test_backend_finalize;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_type_class_add_private (klass, sizeof (LibsocialwebTestBackendPrivate));
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_signal_new ("ready", LIBSOCIALWEB_TEST_TYPE_BACKEND, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 4358 "backend.c"
}


static void libsocialweb_test_backend_instance_init (LibsocialwebTestBackend * self) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv = LIBSOCIALWEB_TEST_BACKEND_GET_PRIVATE (self);
#line 368 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->priv->_name_id = (guint) 0;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self->ref_count = 1;
#line 4369 "backend.c"
}


static void libsocialweb_test_backend_finalize (LibsocialwebTestBackend* obj) {
	LibsocialwebTestBackend * self;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackend);
#line 367 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	_g_object_unref0 (self->priv->_lsw_server);
#line 4379 "backend.c"
}


GType libsocialweb_test_backend_get_type (void) {
	static volatile gsize libsocialweb_test_backend_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_backend_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { libsocialweb_test_value_backend_init, libsocialweb_test_value_backend_free_value, libsocialweb_test_value_backend_copy_value, libsocialweb_test_value_backend_peek_pointer, "p", libsocialweb_test_value_backend_collect_value, "p", libsocialweb_test_value_backend_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (LibsocialwebTestBackendClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) libsocialweb_test_backend_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibsocialwebTestBackend), 0, (GInstanceInitFunc) libsocialweb_test_backend_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType libsocialweb_test_backend_type_id;
		libsocialweb_test_backend_type_id = g_type_register_fundamental (g_type_fundamental_next (), "LibsocialwebTestBackend", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&libsocialweb_test_backend_type_id__volatile, libsocialweb_test_backend_type_id);
	}
	return libsocialweb_test_backend_type_id__volatile;
}


gpointer libsocialweb_test_backend_ref (gpointer instance) {
	LibsocialwebTestBackend* self;
	self = instance;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	g_atomic_int_inc (&self->ref_count);
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	return instance;
#line 4404 "backend.c"
}


void libsocialweb_test_backend_unref (gpointer instance) {
	LibsocialwebTestBackend* self;
	self = instance;
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		LIBSOCIALWEB_TEST_BACKEND_GET_CLASS (self)->finalize (self);
#line 360 "/opt/gnome3/source/folks/tests/lib/libsocialweb/backend.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 4417 "backend.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



